from .base import AccountLinkServiceTransport as AccountLinkServiceTransport
from .grpc import AccountLinkServiceGrpcTransport as AccountLinkServiceGrpcTransport
from .grpc_asyncio import (
    AccountLinkServiceGrpcAsyncIOTransport as AccountLinkServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AccountLinkServiceTransport",
    "AccountLinkServiceGrpcTransport",
    "AccountLinkServiceGrpcAsyncIOTransport",
]



from .async_client import (
    CustomerSkAdNetworkConversionValueSchemaServiceAsyncClient as CustomerSkAdNetworkConversionValueSchemaServiceAsyncClient,
)
from .client import (
    CustomerSkAdNetworkConversionValueSchemaServiceClient as CustomerSkAdNetworkConversionValueSchemaServiceClient,
)

__all__ = [
    "CustomerSkAdNetworkConversionValueSchemaServiceClient",
    "CustomerSkAdNetworkConversionValueSchemaServiceAsyncClient",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v22.enums.types.data_link_status import DataLinkStatusEnum
from google.ads.googleads.v22.resources.types.data_link import DataLink

_M = TypeVar("_M")

class CreateDataLinkRequest(proto.Message):
    customer_id: str
    data_link: DataLink
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        data_link: DataLink = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "data_link"]
    ) -> bool: ...

class CreateDataLinkResponse(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...

class RemoveDataLinkRequest(proto.Message):
    customer_id: str
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "resource_name"]
    ) -> bool: ...

class RemoveDataLinkResponse(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...

class UpdateDataLinkRequest(proto.Message):
    customer_id: str
    data_link_status: DataLinkStatusEnum.DataLinkStatus
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        data_link_status: DataLinkStatusEnum.DataLinkStatus = ...,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "data_link_status", "resource_name"]
    ) -> bool: ...

class UpdateDataLinkResponse(proto.Message):
    resource_name: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["resource_name"]
    ) -> bool: ...



from .base import AdGroupCriterionServiceTransport as AdGroupCriterionServiceTransport
from .grpc import (
    AdGroupCriterionServiceGrpcTransport as AdGroupCriterionServiceGrpcTransport,
)
from .grpc_asyncio import (
    AdGroupCriterionServiceGrpcAsyncIOTransport as AdGroupCriterionServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AdGroupCriterionServiceTransport",
    "AdGroupCriterionServiceGrpcTransport",
    "AdGroupCriterionServiceGrpcAsyncIOTransport",
]



from .base import AssetGroupSignalServiceTransport as AssetGroupSignalServiceTransport
from .grpc import (
    AssetGroupSignalServiceGrpcTransport as AssetGroupSignalServiceGrpcTransport,
)
from .grpc_asyncio import (
    AssetGroupSignalServiceGrpcAsyncIOTransport as AssetGroupSignalServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AssetGroupSignalServiceTransport",
    "AssetGroupSignalServiceGrpcTransport",
    "AssetGroupSignalServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v20.common.types.custom_parameter import CustomParameter
from google.ads.googleads.v20.enums.types.call_conversion_reporting_state import (
    CallConversionReportingStateEnum,
)

_M = TypeVar("_M")

class CallFeedItem(proto.Message):
    phone_number: str
    country_code: str
    call_tracking_enabled: bool
    call_conversion_action: str
    call_conversion_tracking_disabled: bool
    call_conversion_reporting_state: (
        CallConversionReportingStateEnum.CallConversionReportingState
    )
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        phone_number: str = ...,
        country_code: str = ...,
        call_tracking_enabled: bool = ...,
        call_conversion_action: str = ...,
        call_conversion_tracking_disabled: bool = ...,
        call_conversion_reporting_state: CallConversionReportingStateEnum.CallConversionReportingState = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "phone_number",
            "country_code",
            "call_tracking_enabled",
            "call_conversion_action",
            "call_conversion_tracking_disabled",
            "call_conversion_reporting_state",
        ],
    ) -> bool: ...

class CalloutFeedItem(proto.Message):
    callout_text: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        callout_text: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["callout_text"]
    ) -> bool: ...

class SitelinkFeedItem(proto.Message):
    link_text: str
    line1: str
    line2: str
    final_urls: MutableSequence[str]
    final_mobile_urls: MutableSequence[str]
    tracking_url_template: str
    url_custom_parameters: MutableSequence[CustomParameter]
    final_url_suffix: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        link_text: str = ...,
        line1: str = ...,
        line2: str = ...,
        final_urls: MutableSequence[str] = ...,
        final_mobile_urls: MutableSequence[str] = ...,
        tracking_url_template: str = ...,
        url_custom_parameters: MutableSequence[CustomParameter] = ...,
        final_url_suffix: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "link_text",
            "line1",
            "line2",
            "final_urls",
            "final_mobile_urls",
            "tracking_url_template",
            "url_custom_parameters",
            "final_url_suffix",
        ],
    ) -> bool: ...



from .base import PaymentsAccountServiceTransport as PaymentsAccountServiceTransport
from .grpc import (
    PaymentsAccountServiceGrpcTransport as PaymentsAccountServiceGrpcTransport,
)
from .grpc_asyncio import (
    PaymentsAccountServiceGrpcAsyncIOTransport as PaymentsAccountServiceGrpcAsyncIOTransport,
)

__all__ = [
    "PaymentsAccountServiceTransport",
    "PaymentsAccountServiceGrpcTransport",
    "PaymentsAccountServiceGrpcAsyncIOTransport",
]



from .async_client import (
    AudienceInsightsServiceAsyncClient as AudienceInsightsServiceAsyncClient,
)
from .client import AudienceInsightsServiceClient as AudienceInsightsServiceClient

__all__ = ["AudienceInsightsServiceClient", "AudienceInsightsServiceAsyncClient"]



from .base import BatchJobServiceTransport as BatchJobServiceTransport
from .grpc import BatchJobServiceGrpcTransport as BatchJobServiceGrpcTransport
from .grpc_asyncio import (
    BatchJobServiceGrpcAsyncIOTransport as BatchJobServiceGrpcAsyncIOTransport,
)

__all__ = [
    "BatchJobServiceTransport",
    "BatchJobServiceGrpcTransport",
    "BatchJobServiceGrpcAsyncIOTransport",
]



from .async_client import (
    AssetSetAssetServiceAsyncClient as AssetSetAssetServiceAsyncClient,
)
from .client import AssetSetAssetServiceClient as AssetSetAssetServiceClient

__all__ = ["AssetSetAssetServiceClient", "AssetSetAssetServiceAsyncClient"]



import types
from typing import Callable, MutableSequence, Sequence

from _typeshed import Incomplete
from google.api_core import (
    client_options as client_options_lib,
    gapic_v1,
    retry as retries,
)
from google.auth import credentials as ga_credentials

from google.ads.googleads.v23.services.types import keyword_plan_service

from .transports.base import KeywordPlanServiceTransport

__all__ = ["KeywordPlanServiceClient"]

class KeywordPlanServiceClientMeta(type):
    def get_transport_class(
        cls, label: str | None = None
    ) -> type[KeywordPlanServiceTransport]: ...

class KeywordPlanServiceClient(metaclass=KeywordPlanServiceClientMeta):
    DEFAULT_ENDPOINT: str
    DEFAULT_MTLS_ENDPOINT: Incomplete
    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs): ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs): ...
    from_service_account_json = from_service_account_file
    @property
    def transport(self) -> KeywordPlanServiceTransport: ...
    @staticmethod
    def keyword_plan_path(customer_id: str, keyword_plan_id: str) -> str: ...
    @staticmethod
    def parse_keyword_plan_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_billing_account_path(billing_account: str) -> str: ...
    @staticmethod
    def parse_common_billing_account_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_folder_path(folder: str) -> str: ...
    @staticmethod
    def parse_common_folder_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_organization_path(organization: str) -> str: ...
    @staticmethod
    def parse_common_organization_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_project_path(project: str) -> str: ...
    @staticmethod
    def parse_common_project_path(path: str) -> dict[str, str]: ...
    @staticmethod
    def common_location_path(project: str, location: str) -> str: ...
    @staticmethod
    def parse_common_location_path(path: str) -> dict[str, str]: ...
    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: client_options_lib.ClientOptions | None = None
    ): ...
    @property
    def api_endpoint(self): ...
    @property
    def universe_domain(self) -> str: ...
    def __init__(
        self,
        *,
        credentials: ga_credentials.Credentials | None = None,
        transport: str
        | KeywordPlanServiceTransport
        | Callable[..., KeywordPlanServiceTransport]
        | None = None,
        client_options: client_options_lib.ClientOptions | dict | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
    ) -> None: ...
    def mutate_keyword_plans(
        self,
        request: keyword_plan_service.MutateKeywordPlansRequest | dict | None = None,
        *,
        customer_id: str | None = None,
        operations: MutableSequence[keyword_plan_service.KeywordPlanOperation]
        | None = None,
        retry: retries.Retry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> keyword_plan_service.MutateKeywordPlansResponse: ...
    def __enter__(self) -> KeywordPlanServiceClient: ...
    def __exit__(
        self,
        type: type[BaseException] | None,
        value: BaseException | None,
        traceback: types.TracebackType | None,
    ) -> None: ...



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.enums.types.placement_type import PlacementTypeEnum

_M = TypeVar("_M")

class DetailPlacementView(proto.Message):
    resource_name: str
    placement: str
    display_name: str
    group_placement_target_url: str
    target_url: str
    placement_type: PlacementTypeEnum.PlacementType
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        placement: str = ...,
        display_name: str = ...,
        group_placement_target_url: str = ...,
        target_url: str = ...,
        placement_type: PlacementTypeEnum.PlacementType = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "placement",
            "display_name",
            "group_placement_target_url",
            "target_url",
            "placement_type",
        ],
    ) -> bool: ...



from typing import Any, AsyncIterator, Awaitable, Callable, Iterator, Sequence

from _typeshed import Incomplete

from google.ads.googleads.v21.services.types import google_ads_service

OptionalRetry: Incomplete
OptionalAsyncRetry: Incomplete

class SearchPager:
    def __init__(
        self,
        method: Callable[..., google_ads_service.SearchGoogleAdsResponse],
        request: google_ads_service.SearchGoogleAdsRequest,
        response: google_ads_service.SearchGoogleAdsResponse,
        *,
        retry: OptionalRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    def pages(self) -> Iterator[google_ads_service.SearchGoogleAdsResponse]: ...
    def __iter__(self) -> Iterator[google_ads_service.GoogleAdsRow]: ...

class SearchAsyncPager:
    def __init__(
        self,
        method: Callable[..., Awaitable[google_ads_service.SearchGoogleAdsResponse]],
        request: google_ads_service.SearchGoogleAdsRequest,
        response: google_ads_service.SearchGoogleAdsResponse,
        *,
        retry: OptionalAsyncRetry = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    @property
    async def pages(
        self,
    ) -> AsyncIterator[google_ads_service.SearchGoogleAdsResponse]: ...
    def __aiter__(self) -> AsyncIterator[google_ads_service.GoogleAdsRow]: ...



from .async_client import (
    CustomerAssetServiceAsyncClient as CustomerAssetServiceAsyncClient,
)
from .client import CustomerAssetServiceClient as CustomerAssetServiceClient

__all__ = ["CustomerAssetServiceClient", "CustomerAssetServiceAsyncClient"]



from .base import (
    CampaignLifecycleGoalServiceTransport as CampaignLifecycleGoalServiceTransport,
)
from .grpc import (
    CampaignLifecycleGoalServiceGrpcTransport as CampaignLifecycleGoalServiceGrpcTransport,
)
from .grpc_asyncio import (
    CampaignLifecycleGoalServiceGrpcAsyncIOTransport as CampaignLifecycleGoalServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CampaignLifecycleGoalServiceTransport",
    "CampaignLifecycleGoalServiceGrpcTransport",
    "CampaignLifecycleGoalServiceGrpcAsyncIOTransport",
]



from typing import Callable, MutableSequence, Sequence

from _typeshed import Incomplete
from google.api_core import gapic_v1, operation_async, retry_async as retries
from google.api_core.client_options import ClientOptions
from google.auth import credentials as ga_credentials

from google.ads.googleads.v20.services.services.batch_job_service import pagers
from google.ads.googleads.v20.services.types import (
    batch_job_service,
    google_ads_service,
)

from .transports.base import BatchJobServiceTransport

__all__ = ["BatchJobServiceAsyncClient"]

class BatchJobServiceAsyncClient:
    DEFAULT_ENDPOINT: Incomplete
    DEFAULT_MTLS_ENDPOINT: Incomplete
    accessible_bidding_strategy_path: Incomplete
    parse_accessible_bidding_strategy_path: Incomplete
    ad_path: Incomplete
    parse_ad_path: Incomplete
    ad_group_path: Incomplete
    parse_ad_group_path: Incomplete
    ad_group_ad_path: Incomplete
    parse_ad_group_ad_path: Incomplete
    ad_group_ad_label_path: Incomplete
    parse_ad_group_ad_label_path: Incomplete
    ad_group_asset_path: Incomplete
    parse_ad_group_asset_path: Incomplete
    ad_group_bid_modifier_path: Incomplete
    parse_ad_group_bid_modifier_path: Incomplete
    ad_group_criterion_path: Incomplete
    parse_ad_group_criterion_path: Incomplete
    ad_group_criterion_customizer_path: Incomplete
    parse_ad_group_criterion_customizer_path: Incomplete
    ad_group_criterion_label_path: Incomplete
    parse_ad_group_criterion_label_path: Incomplete
    ad_group_customizer_path: Incomplete
    parse_ad_group_customizer_path: Incomplete
    ad_group_label_path: Incomplete
    parse_ad_group_label_path: Incomplete
    ad_parameter_path: Incomplete
    parse_ad_parameter_path: Incomplete
    asset_path: Incomplete
    parse_asset_path: Incomplete
    asset_group_path: Incomplete
    parse_asset_group_path: Incomplete
    asset_group_asset_path: Incomplete
    parse_asset_group_asset_path: Incomplete
    asset_group_listing_group_filter_path: Incomplete
    parse_asset_group_listing_group_filter_path: Incomplete
    asset_group_signal_path: Incomplete
    parse_asset_group_signal_path: Incomplete
    asset_set_path: Incomplete
    parse_asset_set_path: Incomplete
    asset_set_asset_path: Incomplete
    parse_asset_set_asset_path: Incomplete
    audience_path: Incomplete
    parse_audience_path: Incomplete
    batch_job_path: Incomplete
    parse_batch_job_path: Incomplete
    bidding_data_exclusion_path: Incomplete
    parse_bidding_data_exclusion_path: Incomplete
    bidding_seasonality_adjustment_path: Incomplete
    parse_bidding_seasonality_adjustment_path: Incomplete
    bidding_strategy_path: Incomplete
    parse_bidding_strategy_path: Incomplete
    campaign_path: Incomplete
    parse_campaign_path: Incomplete
    campaign_asset_path: Incomplete
    parse_campaign_asset_path: Incomplete
    campaign_asset_set_path: Incomplete
    parse_campaign_asset_set_path: Incomplete
    campaign_bid_modifier_path: Incomplete
    parse_campaign_bid_modifier_path: Incomplete
    campaign_budget_path: Incomplete
    parse_campaign_budget_path: Incomplete
    campaign_conversion_goal_path: Incomplete
    parse_campaign_conversion_goal_path: Incomplete
    campaign_criterion_path: Incomplete
    parse_campaign_criterion_path: Incomplete
    campaign_customizer_path: Incomplete
    parse_campaign_customizer_path: Incomplete
    campaign_draft_path: Incomplete
    parse_campaign_draft_path: Incomplete
    campaign_group_path: Incomplete
    parse_campaign_group_path: Incomplete
    campaign_label_path: Incomplete
    parse_campaign_label_path: Incomplete
    campaign_shared_set_path: Incomplete
    parse_campaign_shared_set_path: Incomplete
    carrier_constant_path: Incomplete
    parse_carrier_constant_path: Incomplete
    combined_audience_path: Incomplete
    parse_combined_audience_path: Incomplete
    conversion_action_path: Incomplete
    parse_conversion_action_path: Incomplete
    conversion_custom_variable_path: Incomplete
    parse_conversion_custom_variable_path: Incomplete
    conversion_goal_campaign_config_path: Incomplete
    parse_conversion_goal_campaign_config_path: Incomplete
    conversion_value_rule_path: Incomplete
    parse_conversion_value_rule_path: Incomplete
    conversion_value_rule_set_path: Incomplete
    parse_conversion_value_rule_set_path: Incomplete
    custom_conversion_goal_path: Incomplete
    parse_custom_conversion_goal_path: Incomplete
    customer_path: Incomplete
    parse_customer_path: Incomplete
    customer_asset_path: Incomplete
    parse_customer_asset_path: Incomplete
    customer_conversion_goal_path: Incomplete
    parse_customer_conversion_goal_path: Incomplete
    customer_customizer_path: Incomplete
    parse_customer_customizer_path: Incomplete
    customer_label_path: Incomplete
    parse_customer_label_path: Incomplete
    customer_negative_criterion_path: Incomplete
    parse_customer_negative_criterion_path: Incomplete
    customizer_attribute_path: Incomplete
    parse_customizer_attribute_path: Incomplete
    detailed_demographic_path: Incomplete
    parse_detailed_demographic_path: Incomplete
    experiment_path: Incomplete
    parse_experiment_path: Incomplete
    experiment_arm_path: Incomplete
    parse_experiment_arm_path: Incomplete
    geo_target_constant_path: Incomplete
    parse_geo_target_constant_path: Incomplete
    keyword_plan_path: Incomplete
    parse_keyword_plan_path: Incomplete
    keyword_plan_ad_group_path: Incomplete
    parse_keyword_plan_ad_group_path: Incomplete
    keyword_plan_ad_group_keyword_path: Incomplete
    parse_keyword_plan_ad_group_keyword_path: Incomplete
    keyword_plan_campaign_path: Incomplete
    parse_keyword_plan_campaign_path: Incomplete
    keyword_plan_campaign_keyword_path: Incomplete
    parse_keyword_plan_campaign_keyword_path: Incomplete
    keyword_theme_constant_path: Incomplete
    parse_keyword_theme_constant_path: Incomplete
    label_path: Incomplete
    parse_label_path: Incomplete
    language_constant_path: Incomplete
    parse_language_constant_path: Incomplete
    life_event_path: Incomplete
    parse_life_event_path: Incomplete
    mobile_app_category_constant_path: Incomplete
    parse_mobile_app_category_constant_path: Incomplete
    mobile_device_constant_path: Incomplete
    parse_mobile_device_constant_path: Incomplete
    operating_system_version_constant_path: Incomplete
    parse_operating_system_version_constant_path: Incomplete
    recommendation_subscription_path: Incomplete
    parse_recommendation_subscription_path: Incomplete
    remarketing_action_path: Incomplete
    parse_remarketing_action_path: Incomplete
    shared_criterion_path: Incomplete
    parse_shared_criterion_path: Incomplete
    shared_set_path: Incomplete
    parse_shared_set_path: Incomplete
    smart_campaign_setting_path: Incomplete
    parse_smart_campaign_setting_path: Incomplete
    topic_constant_path: Incomplete
    parse_topic_constant_path: Incomplete
    user_interest_path: Incomplete
    parse_user_interest_path: Incomplete
    user_list_path: Incomplete
    parse_user_list_path: Incomplete
    common_billing_account_path: Incomplete
    parse_common_billing_account_path: Incomplete
    common_folder_path: Incomplete
    parse_common_folder_path: Incomplete
    common_organization_path: Incomplete
    parse_common_organization_path: Incomplete
    common_project_path: Incomplete
    parse_common_project_path: Incomplete
    common_location_path: Incomplete
    parse_common_location_path: Incomplete
    @classmethod
    def from_service_account_info(cls, info: dict, *args, **kwargs): ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args, **kwargs): ...
    from_service_account_json = from_service_account_file
    @classmethod
    def get_mtls_endpoint_and_cert_source(
        cls, client_options: ClientOptions | None = None
    ): ...
    @property
    def transport(self) -> BatchJobServiceTransport: ...
    @property
    def api_endpoint(self): ...
    @property
    def universe_domain(self) -> str: ...
    get_transport_class: Incomplete
    def __init__(
        self,
        *,
        credentials: ga_credentials.Credentials | None = None,
        transport: str
        | BatchJobServiceTransport
        | Callable[..., BatchJobServiceTransport]
        | None = "grpc_asyncio",
        client_options: ClientOptions | None = None,
        client_info: gapic_v1.client_info.ClientInfo = ...,
    ) -> None: ...
    async def mutate_batch_job(
        self,
        request: batch_job_service.MutateBatchJobRequest | dict | None = None,
        *,
        customer_id: str | None = None,
        operation: batch_job_service.BatchJobOperation | None = None,
        retry: retries.AsyncRetry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> batch_job_service.MutateBatchJobResponse: ...
    async def list_batch_job_results(
        self,
        request: batch_job_service.ListBatchJobResultsRequest | dict | None = None,
        *,
        resource_name: str | None = None,
        retry: retries.AsyncRetry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> pagers.ListBatchJobResultsAsyncPager: ...
    async def run_batch_job(
        self,
        request: batch_job_service.RunBatchJobRequest | dict | None = None,
        *,
        resource_name: str | None = None,
        retry: retries.AsyncRetry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> operation_async.AsyncOperation: ...
    async def add_batch_job_operations(
        self,
        request: batch_job_service.AddBatchJobOperationsRequest | dict | None = None,
        *,
        resource_name: str | None = None,
        sequence_token: str | None = None,
        mutate_operations: MutableSequence[google_ads_service.MutateOperation]
        | None = None,
        retry: retries.AsyncRetry | gapic_v1.method._MethodDefault = ...,
        timeout: float | object = ...,
        metadata: Sequence[tuple[str, str | bytes]] = (),
    ) -> batch_job_service.AddBatchJobOperationsResponse: ...
    async def __aenter__(self) -> BatchJobServiceAsyncClient: ...
    async def __aexit__(self, exc_type, exc, tb) -> None: ...



from .async_client import (
    CustomerClientLinkServiceAsyncClient as CustomerClientLinkServiceAsyncClient,
)
from .client import CustomerClientLinkServiceClient as CustomerClientLinkServiceClient

__all__ = ["CustomerClientLinkServiceClient", "CustomerClientLinkServiceAsyncClient"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v21.enums.types.customizer_attribute_type import (
    CustomizerAttributeTypeEnum,
)

_M = TypeVar("_M")

class CustomizerValue(proto.Message):
    type_: CustomizerAttributeTypeEnum.CustomizerAttributeType
    string_value: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        type_: CustomizerAttributeTypeEnum.CustomizerAttributeType = ...,
        string_value: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["type_", "string_value"]
    ) -> bool: ...



from .base import (
    CustomerNegativeCriterionServiceTransport as CustomerNegativeCriterionServiceTransport,
)
from .grpc import (
    CustomerNegativeCriterionServiceGrpcTransport as CustomerNegativeCriterionServiceGrpcTransport,
)
from .grpc_asyncio import (
    CustomerNegativeCriterionServiceGrpcAsyncIOTransport as CustomerNegativeCriterionServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CustomerNegativeCriterionServiceTransport",
    "CustomerNegativeCriterionServiceGrpcTransport",
    "CustomerNegativeCriterionServiceGrpcAsyncIOTransport",
]



from .async_client import (
    CampaignGroupServiceAsyncClient as CampaignGroupServiceAsyncClient,
)
from .client import CampaignGroupServiceClient as CampaignGroupServiceClient

__all__ = ["CampaignGroupServiceClient", "CampaignGroupServiceAsyncClient"]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v22.common.types.goal_setting import GoalSetting
from google.ads.googleads.v22.enums.types.goal_optimization_eligibility import (
    GoalOptimizationEligibilityEnum,
)
from google.ads.googleads.v22.enums.types.goal_type import GoalTypeEnum

_M = TypeVar("_M")

class Goal(proto.Message):
    resource_name: str
    goal_id: int
    goal_type: GoalTypeEnum.GoalType
    owner_customer: str
    optimization_eligibility: (
        GoalOptimizationEligibilityEnum.GoalOptimizationEligibility
    )
    retention_goal_settings: GoalSetting.RetentionGoal
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        goal_id: int = ...,
        goal_type: GoalTypeEnum.GoalType = ...,
        owner_customer: str = ...,
        optimization_eligibility: GoalOptimizationEligibilityEnum.GoalOptimizationEligibility = ...,
        retention_goal_settings: GoalSetting.RetentionGoal = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "goal_id",
            "goal_type",
            "owner_customer",
            "optimization_eligibility",
            "retention_goal_settings",
        ],
    ) -> bool: ...



from .base import CustomerLabelServiceTransport as CustomerLabelServiceTransport
from .grpc import CustomerLabelServiceGrpcTransport as CustomerLabelServiceGrpcTransport
from .grpc_asyncio import (
    CustomerLabelServiceGrpcAsyncIOTransport as CustomerLabelServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CustomerLabelServiceTransport",
    "CustomerLabelServiceGrpcTransport",
    "CustomerLabelServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping, MutableSequence
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from google.rpc.status_pb2 import Status
from typing_extensions import Literal

from google.ads.googleads.v21.enums.types.local_services_lead_credit_issuance_decision import (
    LocalServicesLeadCreditIssuanceDecisionEnum,
)
from google.ads.googleads.v21.enums.types.local_services_lead_survey_answer import (
    LocalServicesLeadSurveyAnswerEnum,
)
from google.ads.googleads.v21.enums.types.local_services_lead_survey_dissatisfied_reason import (
    LocalServicesLeadSurveyDissatisfiedReasonEnum,
)
from google.ads.googleads.v21.enums.types.local_services_lead_survey_satisfied_reason import (
    LocalServicesLeadSurveySatisfiedReasonEnum,
)

_M = TypeVar("_M")

class AppendLeadConversationRequest(proto.Message):
    customer_id: str
    conversations: MutableSequence[Conversation]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        customer_id: str = ...,
        conversations: MutableSequence[Conversation] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["customer_id", "conversations"]
    ) -> bool: ...

class AppendLeadConversationResponse(proto.Message):
    responses: MutableSequence[ConversationOrError]
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        responses: MutableSequence[ConversationOrError] = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["responses"]
    ) -> bool: ...

class Conversation(proto.Message):
    local_services_lead: str
    text: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        local_services_lead: str = ...,
        text: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["local_services_lead", "text"]
    ) -> bool: ...

class ConversationOrError(proto.Message):
    local_services_lead_conversation: str
    partial_failure_error: Status
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        local_services_lead_conversation: str = ...,
        partial_failure_error: Status = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["local_services_lead_conversation", "partial_failure_error"]
    ) -> bool: ...

class ProvideLeadFeedbackRequest(proto.Message):
    resource_name: str
    survey_answer: LocalServicesLeadSurveyAnswerEnum.SurveyAnswer
    survey_satisfied: SurveySatisfied
    survey_dissatisfied: SurveyDissatisfied
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        survey_answer: LocalServicesLeadSurveyAnswerEnum.SurveyAnswer = ...,
        survey_satisfied: SurveySatisfied = ...,
        survey_dissatisfied: SurveyDissatisfied = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name", "survey_answer", "survey_satisfied", "survey_dissatisfied"
        ],
    ) -> bool: ...

class ProvideLeadFeedbackResponse(proto.Message):
    credit_issuance_decision: (
        LocalServicesLeadCreditIssuanceDecisionEnum.CreditIssuanceDecision
    )
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        credit_issuance_decision: LocalServicesLeadCreditIssuanceDecisionEnum.CreditIssuanceDecision = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["credit_issuance_decision"]
    ) -> bool: ...

class SurveyDissatisfied(proto.Message):
    survey_dissatisfied_reason: (
        LocalServicesLeadSurveyDissatisfiedReasonEnum.SurveyDissatisfiedReason
    )
    other_reason_comment: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        survey_dissatisfied_reason: LocalServicesLeadSurveyDissatisfiedReasonEnum.SurveyDissatisfiedReason = ...,
        other_reason_comment: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["survey_dissatisfied_reason", "other_reason_comment"]
    ) -> bool: ...

class SurveySatisfied(proto.Message):
    survey_satisfied_reason: (
        LocalServicesLeadSurveySatisfiedReasonEnum.SurveySatisfiedReason
    )
    other_reason_comment: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        survey_satisfied_reason: LocalServicesLeadSurveySatisfiedReasonEnum.SurveySatisfiedReason = ...,
        other_reason_comment: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["survey_satisfied_reason", "other_reason_comment"]
    ) -> bool: ...



from .base import (
    ContentCreatorInsightsServiceTransport as ContentCreatorInsightsServiceTransport,
)
from .grpc import (
    ContentCreatorInsightsServiceGrpcTransport as ContentCreatorInsightsServiceGrpcTransport,
)
from .grpc_asyncio import (
    ContentCreatorInsightsServiceGrpcAsyncIOTransport as ContentCreatorInsightsServiceGrpcAsyncIOTransport,
)

__all__ = [
    "ContentCreatorInsightsServiceTransport",
    "ContentCreatorInsightsServiceGrpcTransport",
    "ContentCreatorInsightsServiceGrpcAsyncIOTransport",
]



from .base import (
    KeywordPlanCampaignServiceTransport as KeywordPlanCampaignServiceTransport,
)
from .grpc import (
    KeywordPlanCampaignServiceGrpcTransport as KeywordPlanCampaignServiceGrpcTransport,
)
from .grpc_asyncio import (
    KeywordPlanCampaignServiceGrpcAsyncIOTransport as KeywordPlanCampaignServiceGrpcAsyncIOTransport,
)

__all__ = [
    "KeywordPlanCampaignServiceTransport",
    "KeywordPlanCampaignServiceGrpcTransport",
    "KeywordPlanCampaignServiceGrpcAsyncIOTransport",
]



from .base import (
    CampaignConversionGoalServiceTransport as CampaignConversionGoalServiceTransport,
)
from .grpc import (
    CampaignConversionGoalServiceGrpcTransport as CampaignConversionGoalServiceGrpcTransport,
)
from .grpc_asyncio import (
    CampaignConversionGoalServiceGrpcAsyncIOTransport as CampaignConversionGoalServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CampaignConversionGoalServiceTransport",
    "CampaignConversionGoalServiceGrpcTransport",
    "CampaignConversionGoalServiceGrpcAsyncIOTransport",
]



from .async_client import (
    CampaignGoalConfigServiceAsyncClient as CampaignGoalConfigServiceAsyncClient,
)
from .client import CampaignGoalConfigServiceClient as CampaignGoalConfigServiceClient

__all__ = ["CampaignGoalConfigServiceClient", "CampaignGoalConfigServiceAsyncClient"]



from .base import BenchmarksServiceTransport as BenchmarksServiceTransport
from .grpc import BenchmarksServiceGrpcTransport as BenchmarksServiceGrpcTransport
from .grpc_asyncio import (
    BenchmarksServiceGrpcAsyncIOTransport as BenchmarksServiceGrpcAsyncIOTransport,
)

__all__ = [
    "BenchmarksServiceTransport",
    "BenchmarksServiceGrpcTransport",
    "BenchmarksServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.enums.types.account_link_status import (
    AccountLinkStatusEnum,
)
from google.ads.googleads.v23.enums.types.linked_account_type import (
    LinkedAccountTypeEnum,
)
from google.ads.googleads.v23.enums.types.mobile_app_vendor import MobileAppVendorEnum

_M = TypeVar("_M")

class AccountLink(proto.Message):
    resource_name: str
    account_link_id: int
    status: AccountLinkStatusEnum.AccountLinkStatus
    type_: LinkedAccountTypeEnum.LinkedAccountType
    third_party_app_analytics: ThirdPartyAppAnalyticsLinkIdentifier
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        resource_name: str = ...,
        account_link_id: int = ...,
        status: AccountLinkStatusEnum.AccountLinkStatus = ...,
        type_: LinkedAccountTypeEnum.LinkedAccountType = ...,
        third_party_app_analytics: ThirdPartyAppAnalyticsLinkIdentifier = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "resource_name",
            "account_link_id",
            "status",
            "type_",
            "third_party_app_analytics",
        ],
    ) -> bool: ...

class ThirdPartyAppAnalyticsLinkIdentifier(proto.Message):
    app_analytics_provider_id: int
    app_id: str
    app_vendor: MobileAppVendorEnum.MobileAppVendor
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        app_analytics_provider_id: int = ...,
        app_id: str = ...,
        app_vendor: MobileAppVendorEnum.MobileAppVendor = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["app_analytics_provider_id", "app_id", "app_vendor"]
    ) -> bool: ...



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.common.types.goal_common import (
    CustomerLifecycleOptimizationValueSettings,
)
from google.ads.googleads.v23.enums.types.customer_lifecycle_optimization_mode import (
    CustomerLifecycleOptimizationModeEnum,
)

_M = TypeVar("_M")

class CampaignGoalSettings(proto.Message):
    class CampaignRetentionGoalSettings(proto.Message):
        value_settings_override: CustomerLifecycleOptimizationValueSettings
        target_option: (
            CustomerLifecycleOptimizationModeEnum.CustomerLifecycleOptimizationMode
        )
        def __init__(
            self: _M,
            mapping: _M | Mapping | google.protobuf.message.Message | None = None,
            *,
            ignore_unknown_fields: bool = False,
            value_settings_override: CustomerLifecycleOptimizationValueSettings = ...,
            target_option: CustomerLifecycleOptimizationModeEnum.CustomerLifecycleOptimizationMode = ...,
        ) -> None: ...
        def __contains__(  # type: ignore[override]
            self, key: Literal["value_settings_override", "target_option"]
        ) -> bool: ...

    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...



from .base import CampaignCriterionServiceTransport as CampaignCriterionServiceTransport
from .grpc import (
    CampaignCriterionServiceGrpcTransport as CampaignCriterionServiceGrpcTransport,
)
from .grpc_asyncio import (
    CampaignCriterionServiceGrpcAsyncIOTransport as CampaignCriterionServiceGrpcAsyncIOTransport,
)

__all__ = [
    "CampaignCriterionServiceTransport",
    "CampaignCriterionServiceGrpcTransport",
    "CampaignCriterionServiceGrpcAsyncIOTransport",
]



from .base import AdGroupCustomizerServiceTransport as AdGroupCustomizerServiceTransport
from .grpc import (
    AdGroupCustomizerServiceGrpcTransport as AdGroupCustomizerServiceGrpcTransport,
)
from .grpc_asyncio import (
    AdGroupCustomizerServiceGrpcAsyncIOTransport as AdGroupCustomizerServiceGrpcAsyncIOTransport,
)

__all__ = [
    "AdGroupCustomizerServiceTransport",
    "AdGroupCustomizerServiceGrpcTransport",
    "AdGroupCustomizerServiceGrpcAsyncIOTransport",
]



from .base import (
    ProductLinkInvitationServiceTransport as ProductLinkInvitationServiceTransport,
)
from .grpc import (
    ProductLinkInvitationServiceGrpcTransport as ProductLinkInvitationServiceGrpcTransport,
)
from .grpc_asyncio import (
    ProductLinkInvitationServiceGrpcAsyncIOTransport as ProductLinkInvitationServiceGrpcAsyncIOTransport,
)

__all__ = [
    "ProductLinkInvitationServiceTransport",
    "ProductLinkInvitationServiceGrpcTransport",
    "ProductLinkInvitationServiceGrpcAsyncIOTransport",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

from google.ads.googleads.v23.common.types.asset_policy import AdAssetPolicySummary
from google.ads.googleads.v23.enums.types.asset_performance_label import (
    AssetPerformanceLabelEnum,
)
from google.ads.googleads.v23.enums.types.served_asset_field_type import (
    ServedAssetFieldTypeEnum,
)

_M = TypeVar("_M")

class AdAppDeepLinkAsset(proto.Message):
    asset: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        asset: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["asset"]
    ) -> bool: ...

class AdCallToActionAsset(proto.Message):
    asset: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        asset: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["asset"]
    ) -> bool: ...

class AdDemandGenCarouselCardAsset(proto.Message):
    asset: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        asset: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["asset"]
    ) -> bool: ...

class AdImageAsset(proto.Message):
    asset: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        asset: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["asset"]
    ) -> bool: ...

class AdMediaBundleAsset(proto.Message):
    asset: str
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        asset: str = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["asset"]
    ) -> bool: ...

class AdTextAsset(proto.Message):
    text: str
    pinned_field: ServedAssetFieldTypeEnum.ServedAssetFieldType
    asset_performance_label: AssetPerformanceLabelEnum.AssetPerformanceLabel
    policy_summary_info: AdAssetPolicySummary
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        text: str = ...,
        pinned_field: ServedAssetFieldTypeEnum.ServedAssetFieldType = ...,
        asset_performance_label: AssetPerformanceLabelEnum.AssetPerformanceLabel = ...,
        policy_summary_info: AdAssetPolicySummary = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "text", "pinned_field", "asset_performance_label", "policy_summary_info"
        ],
    ) -> bool: ...

class AdVideoAsset(proto.Message):
    asset: str
    ad_video_asset_info: AdVideoAssetInfo
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        asset: str = ...,
        ad_video_asset_info: AdVideoAssetInfo = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["asset", "ad_video_asset_info"]
    ) -> bool: ...

class AdVideoAssetInfo(proto.Message):
    ad_video_asset_inventory_preferences: AdVideoAssetInventoryPreferences
    ad_video_asset_feature_control: AdVideoAssetLinkFeatureControl
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        ad_video_asset_inventory_preferences: AdVideoAssetInventoryPreferences = ...,
        ad_video_asset_feature_control: AdVideoAssetLinkFeatureControl = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal[
            "ad_video_asset_inventory_preferences", "ad_video_asset_feature_control"
        ],
    ) -> bool: ...

class AdVideoAssetInventoryPreferences(proto.Message):
    in_feed_preference: bool
    in_stream_preference: bool
    shorts_preference: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        in_feed_preference: bool = ...,
        in_stream_preference: bool = ...,
        shorts_preference: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self,
        key: Literal["in_feed_preference", "in_stream_preference", "shorts_preference"],
    ) -> bool: ...

class AdVideoAssetLinkFeatureControl(proto.Message):
    allow_youtube_comments: bool
    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
        allow_youtube_comments: bool = ...,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: Literal["allow_youtube_comments"]
    ) -> bool: ...



from .base import IncentiveServiceTransport as IncentiveServiceTransport
from .grpc import IncentiveServiceGrpcTransport as IncentiveServiceGrpcTransport
from .grpc_asyncio import (
    IncentiveServiceGrpcAsyncIOTransport as IncentiveServiceGrpcAsyncIOTransport,
)

__all__ = [
    "IncentiveServiceTransport",
    "IncentiveServiceGrpcTransport",
    "IncentiveServiceGrpcAsyncIOTransport",
]



from .async_client import (
    AdGroupCriterionLabelServiceAsyncClient as AdGroupCriterionLabelServiceAsyncClient,
)
from .client import (
    AdGroupCriterionLabelServiceClient as AdGroupCriterionLabelServiceClient,
)

__all__ = [
    "AdGroupCriterionLabelServiceClient",
    "AdGroupCriterionLabelServiceAsyncClient",
]



from .types.access_invitation_status import (
    AccessInvitationStatusEnum as AccessInvitationStatusEnum,
)
from .types.access_reason import AccessReasonEnum as AccessReasonEnum
from .types.access_role import AccessRoleEnum as AccessRoleEnum
from .types.account_budget_proposal_status import (
    AccountBudgetProposalStatusEnum as AccountBudgetProposalStatusEnum,
)
from .types.account_budget_proposal_type import (
    AccountBudgetProposalTypeEnum as AccountBudgetProposalTypeEnum,
)
from .types.account_budget_status import (
    AccountBudgetStatusEnum as AccountBudgetStatusEnum,
)
from .types.account_link_status import AccountLinkStatusEnum as AccountLinkStatusEnum
from .types.ad_destination_type import AdDestinationTypeEnum as AdDestinationTypeEnum
from .types.ad_format_type import AdFormatTypeEnum as AdFormatTypeEnum
from .types.ad_group_ad_primary_status import (
    AdGroupAdPrimaryStatusEnum as AdGroupAdPrimaryStatusEnum,
)
from .types.ad_group_ad_primary_status_reason import (
    AdGroupAdPrimaryStatusReasonEnum as AdGroupAdPrimaryStatusReasonEnum,
)
from .types.ad_group_ad_rotation_mode import (
    AdGroupAdRotationModeEnum as AdGroupAdRotationModeEnum,
)
from .types.ad_group_ad_status import AdGroupAdStatusEnum as AdGroupAdStatusEnum
from .types.ad_group_criterion_approval_status import (
    AdGroupCriterionApprovalStatusEnum as AdGroupCriterionApprovalStatusEnum,
)
from .types.ad_group_criterion_primary_status import (
    AdGroupCriterionPrimaryStatusEnum as AdGroupCriterionPrimaryStatusEnum,
)
from .types.ad_group_criterion_primary_status_reason import (
    AdGroupCriterionPrimaryStatusReasonEnum as AdGroupCriterionPrimaryStatusReasonEnum,
)
from .types.ad_group_criterion_status import (
    AdGroupCriterionStatusEnum as AdGroupCriterionStatusEnum,
)
from .types.ad_group_primary_status import (
    AdGroupPrimaryStatusEnum as AdGroupPrimaryStatusEnum,
)
from .types.ad_group_primary_status_reason import (
    AdGroupPrimaryStatusReasonEnum as AdGroupPrimaryStatusReasonEnum,
)
from .types.ad_group_status import AdGroupStatusEnum as AdGroupStatusEnum
from .types.ad_group_type import AdGroupTypeEnum as AdGroupTypeEnum
from .types.ad_network_type import AdNetworkTypeEnum as AdNetworkTypeEnum
from .types.ad_serving_optimization_status import (
    AdServingOptimizationStatusEnum as AdServingOptimizationStatusEnum,
)
from .types.ad_strength import AdStrengthEnum as AdStrengthEnum
from .types.ad_strength_action_item_type import (
    AdStrengthActionItemTypeEnum as AdStrengthActionItemTypeEnum,
)
from .types.ad_sub_network_type import AdSubNetworkTypeEnum as AdSubNetworkTypeEnum
from .types.ad_type import AdTypeEnum as AdTypeEnum
from .types.advertising_channel_sub_type import (
    AdvertisingChannelSubTypeEnum as AdvertisingChannelSubTypeEnum,
)
from .types.advertising_channel_type import (
    AdvertisingChannelTypeEnum as AdvertisingChannelTypeEnum,
)
from .types.age_range_type import AgeRangeTypeEnum as AgeRangeTypeEnum
from .types.android_privacy_interaction_type import (
    AndroidPrivacyInteractionTypeEnum as AndroidPrivacyInteractionTypeEnum,
)
from .types.android_privacy_network_type import (
    AndroidPrivacyNetworkTypeEnum as AndroidPrivacyNetworkTypeEnum,
)
from .types.app_bidding_goal import AppBiddingGoalEnum as AppBiddingGoalEnum
from .types.app_campaign_app_store import (
    AppCampaignAppStoreEnum as AppCampaignAppStoreEnum,
)
from .types.app_campaign_bidding_strategy_goal_type import (
    AppCampaignBiddingStrategyGoalTypeEnum as AppCampaignBiddingStrategyGoalTypeEnum,
)
from .types.app_payment_model_type import (
    AppPaymentModelTypeEnum as AppPaymentModelTypeEnum,
)
from .types.app_url_operating_system_type import (
    AppUrlOperatingSystemTypeEnum as AppUrlOperatingSystemTypeEnum,
)
from .types.application_instance import (
    ApplicationInstanceEnum as ApplicationInstanceEnum,
)
from .types.asset_automation_status import (
    AssetAutomationStatusEnum as AssetAutomationStatusEnum,
)
from .types.asset_automation_type import (
    AssetAutomationTypeEnum as AssetAutomationTypeEnum,
)
from .types.asset_coverage_video_aspect_ratio_requirement import (
    AssetCoverageVideoAspectRatioRequirementEnum as AssetCoverageVideoAspectRatioRequirementEnum,
)
from .types.asset_field_type import AssetFieldTypeEnum as AssetFieldTypeEnum
from .types.asset_group_primary_status import (
    AssetGroupPrimaryStatusEnum as AssetGroupPrimaryStatusEnum,
)
from .types.asset_group_primary_status_reason import (
    AssetGroupPrimaryStatusReasonEnum as AssetGroupPrimaryStatusReasonEnum,
)
from .types.asset_group_signal_approval_status import (
    AssetGroupSignalApprovalStatusEnum as AssetGroupSignalApprovalStatusEnum,
)
from .types.asset_group_status import AssetGroupStatusEnum as AssetGroupStatusEnum
from .types.asset_link_primary_status import (
    AssetLinkPrimaryStatusEnum as AssetLinkPrimaryStatusEnum,
)
from .types.asset_link_primary_status_reason import (
    AssetLinkPrimaryStatusReasonEnum as AssetLinkPrimaryStatusReasonEnum,
)
from .types.asset_link_status import AssetLinkStatusEnum as AssetLinkStatusEnum
from .types.asset_offline_evaluation_error_reasons import (
    AssetOfflineEvaluationErrorReasonsEnum as AssetOfflineEvaluationErrorReasonsEnum,
)
from .types.asset_orientation import AssetOrientationEnum as AssetOrientationEnum
from .types.asset_performance_label import (
    AssetPerformanceLabelEnum as AssetPerformanceLabelEnum,
)
from .types.asset_set_asset_status import (
    AssetSetAssetStatusEnum as AssetSetAssetStatusEnum,
)
from .types.asset_set_link_status import (
    AssetSetLinkStatusEnum as AssetSetLinkStatusEnum,
)
from .types.asset_set_status import AssetSetStatusEnum as AssetSetStatusEnum
from .types.asset_set_type import AssetSetTypeEnum as AssetSetTypeEnum
from .types.asset_source import AssetSourceEnum as AssetSourceEnum
from .types.asset_type import AssetTypeEnum as AssetTypeEnum
from .types.async_action_status import AsyncActionStatusEnum as AsyncActionStatusEnum
from .types.attribution_model import AttributionModelEnum as AttributionModelEnum
from .types.audience_insights_dimension import (
    AudienceInsightsDimensionEnum as AudienceInsightsDimensionEnum,
)
from .types.audience_insights_marketing_objective import (
    AudienceInsightsMarketingObjectiveEnum as AudienceInsightsMarketingObjectiveEnum,
)
from .types.audience_scope import AudienceScopeEnum as AudienceScopeEnum
from .types.audience_status import AudienceStatusEnum as AudienceStatusEnum
from .types.batch_job_status import BatchJobStatusEnum as BatchJobStatusEnum
from .types.benchmarks_marketing_objective import (
    BenchmarksMarketingObjectiveEnum as BenchmarksMarketingObjectiveEnum,
)
from .types.benchmarks_source_type import (
    BenchmarksSourceTypeEnum as BenchmarksSourceTypeEnum,
)
from .types.bid_modifier_source import BidModifierSourceEnum as BidModifierSourceEnum
from .types.bidding_source import BiddingSourceEnum as BiddingSourceEnum
from .types.bidding_strategy_status import (
    BiddingStrategyStatusEnum as BiddingStrategyStatusEnum,
)
from .types.bidding_strategy_system_status import (
    BiddingStrategySystemStatusEnum as BiddingStrategySystemStatusEnum,
)
from .types.bidding_strategy_type import (
    BiddingStrategyTypeEnum as BiddingStrategyTypeEnum,
)
from .types.billing_setup_status import BillingSetupStatusEnum as BillingSetupStatusEnum
from .types.brand_request_rejection_reason import (
    BrandRequestRejectionReasonEnum as BrandRequestRejectionReasonEnum,
)
from .types.brand_safety_suitability import (
    BrandSafetySuitabilityEnum as BrandSafetySuitabilityEnum,
)
from .types.brand_state import BrandStateEnum as BrandStateEnum
from .types.budget_campaign_association_status import (
    BudgetCampaignAssociationStatusEnum as BudgetCampaignAssociationStatusEnum,
)
from .types.budget_delivery_method import (
    BudgetDeliveryMethodEnum as BudgetDeliveryMethodEnum,
)
from .types.budget_period import BudgetPeriodEnum as BudgetPeriodEnum
from .types.budget_status import BudgetStatusEnum as BudgetStatusEnum
from .types.budget_type import BudgetTypeEnum as BudgetTypeEnum
from .types.business_message_call_to_action_type import (
    BusinessMessageCallToActionTypeEnum as BusinessMessageCallToActionTypeEnum,
)
from .types.business_message_provider import (
    BusinessMessageProviderEnum as BusinessMessageProviderEnum,
)
from .types.call_conversion_reporting_state import (
    CallConversionReportingStateEnum as CallConversionReportingStateEnum,
)
from .types.call_to_action_type import CallToActionTypeEnum as CallToActionTypeEnum
from .types.call_tracking_display_location import (
    CallTrackingDisplayLocationEnum as CallTrackingDisplayLocationEnum,
)
from .types.call_type import CallTypeEnum as CallTypeEnum
from .types.campaign_criterion_status import (
    CampaignCriterionStatusEnum as CampaignCriterionStatusEnum,
)
from .types.campaign_draft_status import (
    CampaignDraftStatusEnum as CampaignDraftStatusEnum,
)
from .types.campaign_experiment_type import (
    CampaignExperimentTypeEnum as CampaignExperimentTypeEnum,
)
from .types.campaign_group_status import (
    CampaignGroupStatusEnum as CampaignGroupStatusEnum,
)
from .types.campaign_keyword_match_type import (
    CampaignKeywordMatchTypeEnum as CampaignKeywordMatchTypeEnum,
)
from .types.campaign_primary_status import (
    CampaignPrimaryStatusEnum as CampaignPrimaryStatusEnum,
)
from .types.campaign_primary_status_reason import (
    CampaignPrimaryStatusReasonEnum as CampaignPrimaryStatusReasonEnum,
)
from .types.campaign_serving_status import (
    CampaignServingStatusEnum as CampaignServingStatusEnum,
)
from .types.campaign_shared_set_status import (
    CampaignSharedSetStatusEnum as CampaignSharedSetStatusEnum,
)
from .types.campaign_status import CampaignStatusEnum as CampaignStatusEnum
from .types.chain_relationship_type import (
    ChainRelationshipTypeEnum as ChainRelationshipTypeEnum,
)
from .types.change_client_type import ChangeClientTypeEnum as ChangeClientTypeEnum
from .types.change_event_resource_type import (
    ChangeEventResourceTypeEnum as ChangeEventResourceTypeEnum,
)
from .types.change_status_operation import (
    ChangeStatusOperationEnum as ChangeStatusOperationEnum,
)
from .types.change_status_resource_type import (
    ChangeStatusResourceTypeEnum as ChangeStatusResourceTypeEnum,
)
from .types.click_type import ClickTypeEnum as ClickTypeEnum
from .types.combined_audience_status import (
    CombinedAudienceStatusEnum as CombinedAudienceStatusEnum,
)
from .types.consent_status import ConsentStatusEnum as ConsentStatusEnum
from .types.content_label_type import ContentLabelTypeEnum as ContentLabelTypeEnum
from .types.conversion_action_category import (
    ConversionActionCategoryEnum as ConversionActionCategoryEnum,
)
from .types.conversion_action_counting_type import (
    ConversionActionCountingTypeEnum as ConversionActionCountingTypeEnum,
)
from .types.conversion_action_status import (
    ConversionActionStatusEnum as ConversionActionStatusEnum,
)
from .types.conversion_action_type import (
    ConversionActionTypeEnum as ConversionActionTypeEnum,
)
from .types.conversion_adjustment_type import (
    ConversionAdjustmentTypeEnum as ConversionAdjustmentTypeEnum,
)
from .types.conversion_attribution_event_type import (
    ConversionAttributionEventTypeEnum as ConversionAttributionEventTypeEnum,
)
from .types.conversion_custom_variable_status import (
    ConversionCustomVariableStatusEnum as ConversionCustomVariableStatusEnum,
)
from .types.conversion_customer_type import (
    ConversionCustomerTypeEnum as ConversionCustomerTypeEnum,
)
from .types.conversion_environment_enum import (
    ConversionEnvironmentEnum as ConversionEnvironmentEnum,
)
from .types.conversion_lag_bucket import (
    ConversionLagBucketEnum as ConversionLagBucketEnum,
)
from .types.conversion_or_adjustment_lag_bucket import (
    ConversionOrAdjustmentLagBucketEnum as ConversionOrAdjustmentLagBucketEnum,
)
from .types.conversion_origin import ConversionOriginEnum as ConversionOriginEnum
from .types.conversion_tracking_status_enum import (
    ConversionTrackingStatusEnum as ConversionTrackingStatusEnum,
)
from .types.conversion_value_rule_primary_dimension import (
    ConversionValueRulePrimaryDimensionEnum as ConversionValueRulePrimaryDimensionEnum,
)
from .types.conversion_value_rule_set_status import (
    ConversionValueRuleSetStatusEnum as ConversionValueRuleSetStatusEnum,
)
from .types.conversion_value_rule_status import (
    ConversionValueRuleStatusEnum as ConversionValueRuleStatusEnum,
)
from .types.converting_user_prior_engagement_type_and_ltv_bucket import (
    ConvertingUserPriorEngagementTypeAndLtvBucketEnum as ConvertingUserPriorEngagementTypeAndLtvBucketEnum,
)
from .types.criterion_category_channel_availability_mode import (
    CriterionCategoryChannelAvailabilityModeEnum as CriterionCategoryChannelAvailabilityModeEnum,
)
from .types.criterion_category_locale_availability_mode import (
    CriterionCategoryLocaleAvailabilityModeEnum as CriterionCategoryLocaleAvailabilityModeEnum,
)
from .types.criterion_system_serving_status import (
    CriterionSystemServingStatusEnum as CriterionSystemServingStatusEnum,
)
from .types.criterion_type import CriterionTypeEnum as CriterionTypeEnum
from .types.custom_audience_member_type import (
    CustomAudienceMemberTypeEnum as CustomAudienceMemberTypeEnum,
)
from .types.custom_audience_status import (
    CustomAudienceStatusEnum as CustomAudienceStatusEnum,
)
from .types.custom_audience_type import CustomAudienceTypeEnum as CustomAudienceTypeEnum
from .types.custom_conversion_goal_status import (
    CustomConversionGoalStatusEnum as CustomConversionGoalStatusEnum,
)
from .types.custom_interest_member_type import (
    CustomInterestMemberTypeEnum as CustomInterestMemberTypeEnum,
)
from .types.custom_interest_status import (
    CustomInterestStatusEnum as CustomInterestStatusEnum,
)
from .types.custom_interest_type import CustomInterestTypeEnum as CustomInterestTypeEnum
from .types.customer_acquisition_optimization_mode import (
    CustomerAcquisitionOptimizationModeEnum as CustomerAcquisitionOptimizationModeEnum,
)
from .types.customer_lifecycle_optimization_mode import (
    CustomerLifecycleOptimizationModeEnum as CustomerLifecycleOptimizationModeEnum,
)
from .types.customer_match_upload_key_type import (
    CustomerMatchUploadKeyTypeEnum as CustomerMatchUploadKeyTypeEnum,
)
from .types.customer_pay_per_conversion_eligibility_failure_reason import (
    CustomerPayPerConversionEligibilityFailureReasonEnum as CustomerPayPerConversionEligibilityFailureReasonEnum,
)
from .types.customer_status import CustomerStatusEnum as CustomerStatusEnum
from .types.customizer_attribute_status import (
    CustomizerAttributeStatusEnum as CustomizerAttributeStatusEnum,
)
from .types.customizer_attribute_type import (
    CustomizerAttributeTypeEnum as CustomizerAttributeTypeEnum,
)
from .types.customizer_value_status import (
    CustomizerValueStatusEnum as CustomizerValueStatusEnum,
)
from .types.data_driven_model_status import (
    DataDrivenModelStatusEnum as DataDrivenModelStatusEnum,
)
from .types.data_link_status import DataLinkStatusEnum as DataLinkStatusEnum
from .types.data_link_type import DataLinkTypeEnum as DataLinkTypeEnum
from .types.day_of_week import DayOfWeekEnum as DayOfWeekEnum
from .types.demand_gen_channel_config import (
    DemandGenChannelConfigEnum as DemandGenChannelConfigEnum,
)
from .types.demand_gen_channel_strategy import (
    DemandGenChannelStrategyEnum as DemandGenChannelStrategyEnum,
)
from .types.device import DeviceEnum as DeviceEnum
from .types.display_ad_format_setting import (
    DisplayAdFormatSettingEnum as DisplayAdFormatSettingEnum,
)
from .types.display_upload_product_type import (
    DisplayUploadProductTypeEnum as DisplayUploadProductTypeEnum,
)
from .types.distance_bucket import DistanceBucketEnum as DistanceBucketEnum
from .types.eu_political_advertising_status import (
    EuPoliticalAdvertisingStatusEnum as EuPoliticalAdvertisingStatusEnum,
)
from .types.experiment_metric import ExperimentMetricEnum as ExperimentMetricEnum
from .types.experiment_metric_direction import (
    ExperimentMetricDirectionEnum as ExperimentMetricDirectionEnum,
)
from .types.experiment_status import ExperimentStatusEnum as ExperimentStatusEnum
from .types.experiment_type import ExperimentTypeEnum as ExperimentTypeEnum
from .types.external_conversion_source import (
    ExternalConversionSourceEnum as ExternalConversionSourceEnum,
)
from .types.fixed_cpm_goal import FixedCpmGoalEnum as FixedCpmGoalEnum
from .types.fixed_cpm_target_frequency_time_unit import (
    FixedCpmTargetFrequencyTimeUnitEnum as FixedCpmTargetFrequencyTimeUnitEnum,
)
from .types.frequency_cap_event_type import (
    FrequencyCapEventTypeEnum as FrequencyCapEventTypeEnum,
)
from .types.frequency_cap_level import FrequencyCapLevelEnum as FrequencyCapLevelEnum
from .types.frequency_cap_time_unit import (
    FrequencyCapTimeUnitEnum as FrequencyCapTimeUnitEnum,
)
from .types.gender_type import GenderTypeEnum as GenderTypeEnum
from .types.geo_target_constant_status import (
    GeoTargetConstantStatusEnum as GeoTargetConstantStatusEnum,
)
from .types.geo_targeting_type import GeoTargetingTypeEnum as GeoTargetingTypeEnum
from .types.goal_config_level import GoalConfigLevelEnum as GoalConfigLevelEnum
from .types.goal_optimization_eligibility import (
    GoalOptimizationEligibilityEnum as GoalOptimizationEligibilityEnum,
)
from .types.goal_type import GoalTypeEnum as GoalTypeEnum
from .types.google_ads_field_category import (
    GoogleAdsFieldCategoryEnum as GoogleAdsFieldCategoryEnum,
)
from .types.google_ads_field_data_type import (
    GoogleAdsFieldDataTypeEnum as GoogleAdsFieldDataTypeEnum,
)
from .types.google_voice_call_status import (
    GoogleVoiceCallStatusEnum as GoogleVoiceCallStatusEnum,
)
from .types.hotel_asset_suggestion_status import (
    HotelAssetSuggestionStatusEnum as HotelAssetSuggestionStatusEnum,
)
from .types.hotel_date_selection_type import (
    HotelDateSelectionTypeEnum as HotelDateSelectionTypeEnum,
)
from .types.hotel_price_bucket import HotelPriceBucketEnum as HotelPriceBucketEnum
from .types.hotel_rate_type import HotelRateTypeEnum as HotelRateTypeEnum
from .types.hotel_reconciliation_status import (
    HotelReconciliationStatusEnum as HotelReconciliationStatusEnum,
)
from .types.identity_verification_program import (
    IdentityVerificationProgramEnum as IdentityVerificationProgramEnum,
)
from .types.identity_verification_program_status import (
    IdentityVerificationProgramStatusEnum as IdentityVerificationProgramStatusEnum,
)
from .types.incentive_state import IncentiveStateEnum as IncentiveStateEnum
from .types.income_range_type import IncomeRangeTypeEnum as IncomeRangeTypeEnum
from .types.insights_knowledge_graph_entity_capabilities import (
    InsightsKnowledgeGraphEntityCapabilitiesEnum as InsightsKnowledgeGraphEntityCapabilitiesEnum,
)
from .types.insights_trend import InsightsTrendEnum as InsightsTrendEnum
from .types.interaction_event_type import (
    InteractionEventTypeEnum as InteractionEventTypeEnum,
)
from .types.interaction_type import InteractionTypeEnum as InteractionTypeEnum
from .types.invoice_type import InvoiceTypeEnum as InvoiceTypeEnum
from .types.keyword_match_type import KeywordMatchTypeEnum as KeywordMatchTypeEnum
from .types.keyword_plan_aggregate_metric_type import (
    KeywordPlanAggregateMetricTypeEnum as KeywordPlanAggregateMetricTypeEnum,
)
from .types.keyword_plan_competition_level import (
    KeywordPlanCompetitionLevelEnum as KeywordPlanCompetitionLevelEnum,
)
from .types.keyword_plan_concept_group_type import (
    KeywordPlanConceptGroupTypeEnum as KeywordPlanConceptGroupTypeEnum,
)
from .types.keyword_plan_forecast_interval import (
    KeywordPlanForecastIntervalEnum as KeywordPlanForecastIntervalEnum,
)
from .types.keyword_plan_keyword_annotation import (
    KeywordPlanKeywordAnnotationEnum as KeywordPlanKeywordAnnotationEnum,
)
from .types.keyword_plan_network import KeywordPlanNetworkEnum as KeywordPlanNetworkEnum
from .types.label_status import LabelStatusEnum as LabelStatusEnum
from .types.landing_page_source import LandingPageSourceEnum as LandingPageSourceEnum
from .types.lead_form_call_to_action_type import (
    LeadFormCallToActionTypeEnum as LeadFormCallToActionTypeEnum,
)
from .types.lead_form_desired_intent import (
    LeadFormDesiredIntentEnum as LeadFormDesiredIntentEnum,
)
from .types.lead_form_field_user_input_type import (
    LeadFormFieldUserInputTypeEnum as LeadFormFieldUserInputTypeEnum,
)
from .types.lead_form_post_submit_call_to_action_type import (
    LeadFormPostSubmitCallToActionTypeEnum as LeadFormPostSubmitCallToActionTypeEnum,
)
from .types.legacy_app_install_ad_app_store import (
    LegacyAppInstallAdAppStoreEnum as LegacyAppInstallAdAppStoreEnum,
)
from .types.linked_account_type import LinkedAccountTypeEnum as LinkedAccountTypeEnum
from .types.linked_product_type import LinkedProductTypeEnum as LinkedProductTypeEnum
from .types.listing_group_filter_custom_attribute_index import (
    ListingGroupFilterCustomAttributeIndexEnum as ListingGroupFilterCustomAttributeIndexEnum,
)
from .types.listing_group_filter_listing_source import (
    ListingGroupFilterListingSourceEnum as ListingGroupFilterListingSourceEnum,
)
from .types.listing_group_filter_product_category_level import (
    ListingGroupFilterProductCategoryLevelEnum as ListingGroupFilterProductCategoryLevelEnum,
)
from .types.listing_group_filter_product_channel import (
    ListingGroupFilterProductChannelEnum as ListingGroupFilterProductChannelEnum,
)
from .types.listing_group_filter_product_condition import (
    ListingGroupFilterProductConditionEnum as ListingGroupFilterProductConditionEnum,
)
from .types.listing_group_filter_product_type_level import (
    ListingGroupFilterProductTypeLevelEnum as ListingGroupFilterProductTypeLevelEnum,
)
from .types.listing_group_filter_type_enum import (
    ListingGroupFilterTypeEnum as ListingGroupFilterTypeEnum,
)
from .types.listing_group_type import ListingGroupTypeEnum as ListingGroupTypeEnum
from .types.listing_type import ListingTypeEnum as ListingTypeEnum
from .types.local_services_business_registration_check_rejection_reason import (
    LocalServicesBusinessRegistrationCheckRejectionReasonEnum as LocalServicesBusinessRegistrationCheckRejectionReasonEnum,
)
from .types.local_services_business_registration_type import (
    LocalServicesBusinessRegistrationTypeEnum as LocalServicesBusinessRegistrationTypeEnum,
)
from .types.local_services_conversation_type import (
    LocalServicesLeadConversationTypeEnum as LocalServicesLeadConversationTypeEnum,
)
from .types.local_services_employee_status import (
    LocalServicesEmployeeStatusEnum as LocalServicesEmployeeStatusEnum,
)
from .types.local_services_employee_type import (
    LocalServicesEmployeeTypeEnum as LocalServicesEmployeeTypeEnum,
)
from .types.local_services_insurance_rejection_reason import (
    LocalServicesInsuranceRejectionReasonEnum as LocalServicesInsuranceRejectionReasonEnum,
)
from .types.local_services_lead_credit_issuance_decision import (
    LocalServicesLeadCreditIssuanceDecisionEnum as LocalServicesLeadCreditIssuanceDecisionEnum,
)
from .types.local_services_lead_credit_state import (
    LocalServicesCreditStateEnum as LocalServicesCreditStateEnum,
)
from .types.local_services_lead_status import (
    LocalServicesLeadStatusEnum as LocalServicesLeadStatusEnum,
)
from .types.local_services_lead_survey_answer import (
    LocalServicesLeadSurveyAnswerEnum as LocalServicesLeadSurveyAnswerEnum,
)
from .types.local_services_lead_survey_dissatisfied_reason import (
    LocalServicesLeadSurveyDissatisfiedReasonEnum as LocalServicesLeadSurveyDissatisfiedReasonEnum,
)
from .types.local_services_lead_survey_satisfied_reason import (
    LocalServicesLeadSurveySatisfiedReasonEnum as LocalServicesLeadSurveySatisfiedReasonEnum,
)
from .types.local_services_lead_type import (
    LocalServicesLeadTypeEnum as LocalServicesLeadTypeEnum,
)
from .types.local_services_license_rejection_reason import (
    LocalServicesLicenseRejectionReasonEnum as LocalServicesLicenseRejectionReasonEnum,
)
from .types.local_services_participant_type import (
    LocalServicesParticipantTypeEnum as LocalServicesParticipantTypeEnum,
)
from .types.local_services_verification_artifact_status import (
    LocalServicesVerificationArtifactStatusEnum as LocalServicesVerificationArtifactStatusEnum,
)
from .types.local_services_verification_artifact_type import (
    LocalServicesVerificationArtifactTypeEnum as LocalServicesVerificationArtifactTypeEnum,
)
from .types.local_services_verification_status import (
    LocalServicesVerificationStatusEnum as LocalServicesVerificationStatusEnum,
)
from .types.location_group_radius_units import (
    LocationGroupRadiusUnitsEnum as LocationGroupRadiusUnitsEnum,
)
from .types.location_ownership_type import (
    LocationOwnershipTypeEnum as LocationOwnershipTypeEnum,
)
from .types.location_source_type import LocationSourceTypeEnum as LocationSourceTypeEnum
from .types.location_string_filter_type import (
    LocationStringFilterTypeEnum as LocationStringFilterTypeEnum,
)
from .types.lookalike_expansion_level import (
    LookalikeExpansionLevelEnum as LookalikeExpansionLevelEnum,
)
from .types.manager_link_status import ManagerLinkStatusEnum as ManagerLinkStatusEnum
from .types.match_type import MatchTypeEnum as MatchTypeEnum
from .types.media_type import MediaTypeEnum as MediaTypeEnum
from .types.mime_type import MimeTypeEnum as MimeTypeEnum
from .types.minute_of_hour import MinuteOfHourEnum as MinuteOfHourEnum
from .types.mobile_app_vendor import MobileAppVendorEnum as MobileAppVendorEnum
from .types.mobile_device_type import MobileDeviceTypeEnum as MobileDeviceTypeEnum
from .types.month_of_year import MonthOfYearEnum as MonthOfYearEnum
from .types.negative_geo_target_type import (
    NegativeGeoTargetTypeEnum as NegativeGeoTargetTypeEnum,
)
from .types.non_skippable_max_duration import (
    NonSkippableMaxDurationEnum as NonSkippableMaxDurationEnum,
)
from .types.non_skippable_min_duration import (
    NonSkippableMinDurationEnum as NonSkippableMinDurationEnum,
)
from .types.offline_conversion_diagnostic_status_enum import (
    OfflineConversionDiagnosticStatusEnum as OfflineConversionDiagnosticStatusEnum,
)
from .types.offline_event_upload_client_enum import (
    OfflineEventUploadClientEnum as OfflineEventUploadClientEnum,
)
from .types.offline_user_data_job_failure_reason import (
    OfflineUserDataJobFailureReasonEnum as OfflineUserDataJobFailureReasonEnum,
)
from .types.offline_user_data_job_match_rate_range import (
    OfflineUserDataJobMatchRateRangeEnum as OfflineUserDataJobMatchRateRangeEnum,
)
from .types.offline_user_data_job_status import (
    OfflineUserDataJobStatusEnum as OfflineUserDataJobStatusEnum,
)
from .types.offline_user_data_job_type import (
    OfflineUserDataJobTypeEnum as OfflineUserDataJobTypeEnum,
)
from .types.operating_system_version_operator_type import (
    OperatingSystemVersionOperatorTypeEnum as OperatingSystemVersionOperatorTypeEnum,
)
from .types.optimization_goal_type import (
    OptimizationGoalTypeEnum as OptimizationGoalTypeEnum,
)
from .types.parental_status_type import ParentalStatusTypeEnum as ParentalStatusTypeEnum
from .types.payment_mode import PaymentModeEnum as PaymentModeEnum
from .types.performance_max_upgrade_status import (
    PerformanceMaxUpgradeStatusEnum as PerformanceMaxUpgradeStatusEnum,
)
from .types.placement_type import PlacementTypeEnum as PlacementTypeEnum
from .types.policy_approval_status import (
    PolicyApprovalStatusEnum as PolicyApprovalStatusEnum,
)
from .types.policy_review_status import PolicyReviewStatusEnum as PolicyReviewStatusEnum
from .types.policy_topic_entry_type import (
    PolicyTopicEntryTypeEnum as PolicyTopicEntryTypeEnum,
)
from .types.policy_topic_evidence_destination_mismatch_url_type import (
    PolicyTopicEvidenceDestinationMismatchUrlTypeEnum as PolicyTopicEvidenceDestinationMismatchUrlTypeEnum,
)
from .types.policy_topic_evidence_destination_not_working_device import (
    PolicyTopicEvidenceDestinationNotWorkingDeviceEnum as PolicyTopicEvidenceDestinationNotWorkingDeviceEnum,
)
from .types.policy_topic_evidence_destination_not_working_dns_error_type import (
    PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum as PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum,
)
from .types.positive_geo_target_type import (
    PositiveGeoTargetTypeEnum as PositiveGeoTargetTypeEnum,
)
from .types.price_extension_price_qualifier import (
    PriceExtensionPriceQualifierEnum as PriceExtensionPriceQualifierEnum,
)
from .types.price_extension_price_unit import (
    PriceExtensionPriceUnitEnum as PriceExtensionPriceUnitEnum,
)
from .types.price_extension_type import PriceExtensionTypeEnum as PriceExtensionTypeEnum
from .types.product_availability import (
    ProductAvailabilityEnum as ProductAvailabilityEnum,
)
from .types.product_category_level import (
    ProductCategoryLevelEnum as ProductCategoryLevelEnum,
)
from .types.product_category_state import (
    ProductCategoryStateEnum as ProductCategoryStateEnum,
)
from .types.product_channel import ProductChannelEnum as ProductChannelEnum
from .types.product_channel_exclusivity import (
    ProductChannelExclusivityEnum as ProductChannelExclusivityEnum,
)
from .types.product_condition import ProductConditionEnum as ProductConditionEnum
from .types.product_custom_attribute_index import (
    ProductCustomAttributeIndexEnum as ProductCustomAttributeIndexEnum,
)
from .types.product_issue_severity import (
    ProductIssueSeverityEnum as ProductIssueSeverityEnum,
)
from .types.product_link_invitation_status import (
    ProductLinkInvitationStatusEnum as ProductLinkInvitationStatusEnum,
)
from .types.product_status import ProductStatusEnum as ProductStatusEnum
from .types.product_type_level import ProductTypeLevelEnum as ProductTypeLevelEnum
from .types.promotion_barcode_type import (
    PromotionBarcodeTypeEnum as PromotionBarcodeTypeEnum,
)
from .types.promotion_extension_discount_modifier import (
    PromotionExtensionDiscountModifierEnum as PromotionExtensionDiscountModifierEnum,
)
from .types.promotion_extension_occasion import (
    PromotionExtensionOccasionEnum as PromotionExtensionOccasionEnum,
)
from .types.proximity_radius_units import (
    ProximityRadiusUnitsEnum as ProximityRadiusUnitsEnum,
)
from .types.quality_score_bucket import QualityScoreBucketEnum as QualityScoreBucketEnum
from .types.reach_plan_age_range import ReachPlanAgeRangeEnum as ReachPlanAgeRangeEnum
from .types.reach_plan_conversion_rate_model import (
    ReachPlanConversionRateModelEnum as ReachPlanConversionRateModelEnum,
)
from .types.reach_plan_network import ReachPlanNetworkEnum as ReachPlanNetworkEnum
from .types.reach_plan_plannable_user_list_status import (
    ReachPlanPlannableUserListStatusEnum as ReachPlanPlannableUserListStatusEnum,
)
from .types.reach_plan_surface import ReachPlanSurfaceEnum as ReachPlanSurfaceEnum
from .types.recommendation_subscription_status import (
    RecommendationSubscriptionStatusEnum as RecommendationSubscriptionStatusEnum,
)
from .types.recommendation_type import RecommendationTypeEnum as RecommendationTypeEnum
from .types.regulatory_fee_type import RegulatoryFeeTypeEnum as RegulatoryFeeTypeEnum
from .types.resource_change_operation import (
    ResourceChangeOperationEnum as ResourceChangeOperationEnum,
)
from .types.resource_limit_type import ResourceLimitTypeEnum as ResourceLimitTypeEnum
from .types.response_content_type import (
    ResponseContentTypeEnum as ResponseContentTypeEnum,
)
from .types.search_engine_results_page_type import (
    SearchEngineResultsPageTypeEnum as SearchEngineResultsPageTypeEnum,
)
from .types.search_term_match_source import (
    SearchTermMatchSourceEnum as SearchTermMatchSourceEnum,
)
from .types.search_term_match_type import (
    SearchTermMatchTypeEnum as SearchTermMatchTypeEnum,
)
from .types.search_term_targeting_status import (
    SearchTermTargetingStatusEnum as SearchTermTargetingStatusEnum,
)
from .types.seasonality_event_scope import (
    SeasonalityEventScopeEnum as SeasonalityEventScopeEnum,
)
from .types.seasonality_event_status import (
    SeasonalityEventStatusEnum as SeasonalityEventStatusEnum,
)
from .types.served_asset_field_type import (
    ServedAssetFieldTypeEnum as ServedAssetFieldTypeEnum,
)
from .types.shared_set_status import SharedSetStatusEnum as SharedSetStatusEnum
from .types.shared_set_type import SharedSetTypeEnum as SharedSetTypeEnum
from .types.shopping_add_products_to_campaign_recommendation_enum import (
    ShoppingAddProductsToCampaignRecommendationEnum as ShoppingAddProductsToCampaignRecommendationEnum,
)
from .types.simulation_modification_method import (
    SimulationModificationMethodEnum as SimulationModificationMethodEnum,
)
from .types.simulation_type import SimulationTypeEnum as SimulationTypeEnum
from .types.sk_ad_network_ad_event_type import (
    SkAdNetworkAdEventTypeEnum as SkAdNetworkAdEventTypeEnum,
)
from .types.sk_ad_network_attribution_credit import (
    SkAdNetworkAttributionCreditEnum as SkAdNetworkAttributionCreditEnum,
)
from .types.sk_ad_network_coarse_conversion_value import (
    SkAdNetworkCoarseConversionValueEnum as SkAdNetworkCoarseConversionValueEnum,
)
from .types.sk_ad_network_source_type import (
    SkAdNetworkSourceTypeEnum as SkAdNetworkSourceTypeEnum,
)
from .types.sk_ad_network_user_type import (
    SkAdNetworkUserTypeEnum as SkAdNetworkUserTypeEnum,
)
from .types.slot import SlotEnum as SlotEnum
from .types.smart_campaign_not_eligible_reason import (
    SmartCampaignNotEligibleReasonEnum as SmartCampaignNotEligibleReasonEnum,
)
from .types.smart_campaign_status import (
    SmartCampaignStatusEnum as SmartCampaignStatusEnum,
)
from .types.spending_limit_type import SpendingLimitTypeEnum as SpendingLimitTypeEnum
from .types.summary_row_setting import SummaryRowSettingEnum as SummaryRowSettingEnum
from .types.system_managed_entity_source import (
    SystemManagedResourceSourceEnum as SystemManagedResourceSourceEnum,
)
from .types.target_cpa_opt_in_recommendation_goal import (
    TargetCpaOptInRecommendationGoalEnum as TargetCpaOptInRecommendationGoalEnum,
)
from .types.target_frequency_time_unit import (
    TargetFrequencyTimeUnitEnum as TargetFrequencyTimeUnitEnum,
)
from .types.target_impression_share_location import (
    TargetImpressionShareLocationEnum as TargetImpressionShareLocationEnum,
)
from .types.targeting_dimension import TargetingDimensionEnum as TargetingDimensionEnum
from .types.third_party_brand_lift_integration_partner import (
    ThirdPartyBrandLiftIntegrationPartnerEnum as ThirdPartyBrandLiftIntegrationPartnerEnum,
)
from .types.third_party_brand_safety_integration_partner import (
    ThirdPartyBrandSafetyIntegrationPartnerEnum as ThirdPartyBrandSafetyIntegrationPartnerEnum,
)
from .types.third_party_reach_integration_partner import (
    ThirdPartyReachIntegrationPartnerEnum as ThirdPartyReachIntegrationPartnerEnum,
)
from .types.third_party_viewability_integration_partner import (
    ThirdPartyViewabilityIntegrationPartnerEnum as ThirdPartyViewabilityIntegrationPartnerEnum,
)
from .types.time_type import TimeTypeEnum as TimeTypeEnum
from .types.tracking_code_page_format import (
    TrackingCodePageFormatEnum as TrackingCodePageFormatEnum,
)
from .types.tracking_code_type import TrackingCodeTypeEnum as TrackingCodeTypeEnum
from .types.unit_of_measure import UnitOfMeasureEnum as UnitOfMeasureEnum
from .types.user_identifier_source import (
    UserIdentifierSourceEnum as UserIdentifierSourceEnum,
)
from .types.user_interest_taxonomy_type import (
    UserInterestTaxonomyTypeEnum as UserInterestTaxonomyTypeEnum,
)
from .types.user_list_access_status import (
    UserListAccessStatusEnum as UserListAccessStatusEnum,
)
from .types.user_list_closing_reason import (
    UserListClosingReasonEnum as UserListClosingReasonEnum,
)
from .types.user_list_crm_data_source_type import (
    UserListCrmDataSourceTypeEnum as UserListCrmDataSourceTypeEnum,
)
from .types.user_list_customer_type_category import (
    UserListCustomerTypeCategoryEnum as UserListCustomerTypeCategoryEnum,
)
from .types.user_list_date_rule_item_operator import (
    UserListDateRuleItemOperatorEnum as UserListDateRuleItemOperatorEnum,
)
from .types.user_list_flexible_rule_operator import (
    UserListFlexibleRuleOperatorEnum as UserListFlexibleRuleOperatorEnum,
)
from .types.user_list_logical_rule_operator import (
    UserListLogicalRuleOperatorEnum as UserListLogicalRuleOperatorEnum,
)
from .types.user_list_membership_status import (
    UserListMembershipStatusEnum as UserListMembershipStatusEnum,
)
from .types.user_list_number_rule_item_operator import (
    UserListNumberRuleItemOperatorEnum as UserListNumberRuleItemOperatorEnum,
)
from .types.user_list_prepopulation_status import (
    UserListPrepopulationStatusEnum as UserListPrepopulationStatusEnum,
)
from .types.user_list_rule_type import UserListRuleTypeEnum as UserListRuleTypeEnum
from .types.user_list_size_range import UserListSizeRangeEnum as UserListSizeRangeEnum
from .types.user_list_string_rule_item_operator import (
    UserListStringRuleItemOperatorEnum as UserListStringRuleItemOperatorEnum,
)
from .types.user_list_type import UserListTypeEnum as UserListTypeEnum
from .types.value_rule_device_type import (
    ValueRuleDeviceTypeEnum as ValueRuleDeviceTypeEnum,
)
from .types.value_rule_geo_location_match_type import (
    ValueRuleGeoLocationMatchTypeEnum as ValueRuleGeoLocationMatchTypeEnum,
)
from .types.value_rule_operation import ValueRuleOperationEnum as ValueRuleOperationEnum
from .types.value_rule_set_attachment_type import (
    ValueRuleSetAttachmentTypeEnum as ValueRuleSetAttachmentTypeEnum,
)
from .types.value_rule_set_dimension import (
    ValueRuleSetDimensionEnum as ValueRuleSetDimensionEnum,
)
from .types.vanity_pharma_display_url_mode import (
    VanityPharmaDisplayUrlModeEnum as VanityPharmaDisplayUrlModeEnum,
)
from .types.vanity_pharma_text import VanityPharmaTextEnum as VanityPharmaTextEnum
from .types.vertical_ads_item_vertical_type import (
    VerticalAdsItemVerticalTypeEnum as VerticalAdsItemVerticalTypeEnum,
)
from .types.video_ad_format_restriction import (
    VideoAdFormatRestrictionEnum as VideoAdFormatRestrictionEnum,
)
from .types.video_ad_sequence_interaction_type import (
    VideoAdSequenceInteractionTypeEnum as VideoAdSequenceInteractionTypeEnum,
)
from .types.video_ad_sequence_minimum_duration import (
    VideoAdSequenceMinimumDurationEnum as VideoAdSequenceMinimumDurationEnum,
)
from .types.video_thumbnail import VideoThumbnailEnum as VideoThumbnailEnum
from .types.webpage_condition_operand import (
    WebpageConditionOperandEnum as WebpageConditionOperandEnum,
)
from .types.webpage_condition_operator import (
    WebpageConditionOperatorEnum as WebpageConditionOperatorEnum,
)
from .types.youtube_video_property import (
    YouTubeVideoPropertyEnum as YouTubeVideoPropertyEnum,
)

__all__ = [
    "AccessInvitationStatusEnum",
    "AccessReasonEnum",
    "AccessRoleEnum",
    "AccountBudgetProposalStatusEnum",
    "AccountBudgetProposalTypeEnum",
    "AccountBudgetStatusEnum",
    "AccountLinkStatusEnum",
    "AdDestinationTypeEnum",
    "AdFormatTypeEnum",
    "AdGroupAdPrimaryStatusEnum",
    "AdGroupAdPrimaryStatusReasonEnum",
    "AdGroupAdRotationModeEnum",
    "AdGroupAdStatusEnum",
    "AdGroupCriterionApprovalStatusEnum",
    "AdGroupCriterionPrimaryStatusEnum",
    "AdGroupCriterionPrimaryStatusReasonEnum",
    "AdGroupCriterionStatusEnum",
    "AdGroupPrimaryStatusEnum",
    "AdGroupPrimaryStatusReasonEnum",
    "AdGroupStatusEnum",
    "AdGroupTypeEnum",
    "AdNetworkTypeEnum",
    "AdServingOptimizationStatusEnum",
    "AdStrengthActionItemTypeEnum",
    "AdStrengthEnum",
    "AdSubNetworkTypeEnum",
    "AdTypeEnum",
    "AdvertisingChannelSubTypeEnum",
    "AdvertisingChannelTypeEnum",
    "AgeRangeTypeEnum",
    "AndroidPrivacyInteractionTypeEnum",
    "AndroidPrivacyNetworkTypeEnum",
    "AppBiddingGoalEnum",
    "AppCampaignAppStoreEnum",
    "AppCampaignBiddingStrategyGoalTypeEnum",
    "AppPaymentModelTypeEnum",
    "AppUrlOperatingSystemTypeEnum",
    "ApplicationInstanceEnum",
    "AssetAutomationStatusEnum",
    "AssetAutomationTypeEnum",
    "AssetCoverageVideoAspectRatioRequirementEnum",
    "AssetFieldTypeEnum",
    "AssetGroupPrimaryStatusEnum",
    "AssetGroupPrimaryStatusReasonEnum",
    "AssetGroupSignalApprovalStatusEnum",
    "AssetGroupStatusEnum",
    "AssetLinkPrimaryStatusEnum",
    "AssetLinkPrimaryStatusReasonEnum",
    "AssetLinkStatusEnum",
    "AssetOfflineEvaluationErrorReasonsEnum",
    "AssetOrientationEnum",
    "AssetPerformanceLabelEnum",
    "AssetSetAssetStatusEnum",
    "AssetSetLinkStatusEnum",
    "AssetSetStatusEnum",
    "AssetSetTypeEnum",
    "AssetSourceEnum",
    "AssetTypeEnum",
    "AsyncActionStatusEnum",
    "AttributionModelEnum",
    "AudienceInsightsDimensionEnum",
    "AudienceInsightsMarketingObjectiveEnum",
    "AudienceScopeEnum",
    "AudienceStatusEnum",
    "BatchJobStatusEnum",
    "BenchmarksMarketingObjectiveEnum",
    "BenchmarksSourceTypeEnum",
    "BidModifierSourceEnum",
    "BiddingSourceEnum",
    "BiddingStrategyStatusEnum",
    "BiddingStrategySystemStatusEnum",
    "BiddingStrategyTypeEnum",
    "BillingSetupStatusEnum",
    "BrandRequestRejectionReasonEnum",
    "BrandSafetySuitabilityEnum",
    "BrandStateEnum",
    "BudgetCampaignAssociationStatusEnum",
    "BudgetDeliveryMethodEnum",
    "BudgetPeriodEnum",
    "BudgetStatusEnum",
    "BudgetTypeEnum",
    "BusinessMessageCallToActionTypeEnum",
    "BusinessMessageProviderEnum",
    "CallConversionReportingStateEnum",
    "CallToActionTypeEnum",
    "CallTrackingDisplayLocationEnum",
    "CallTypeEnum",
    "CampaignCriterionStatusEnum",
    "CampaignDraftStatusEnum",
    "CampaignExperimentTypeEnum",
    "CampaignGroupStatusEnum",
    "CampaignKeywordMatchTypeEnum",
    "CampaignPrimaryStatusEnum",
    "CampaignPrimaryStatusReasonEnum",
    "CampaignServingStatusEnum",
    "CampaignSharedSetStatusEnum",
    "CampaignStatusEnum",
    "ChainRelationshipTypeEnum",
    "ChangeClientTypeEnum",
    "ChangeEventResourceTypeEnum",
    "ChangeStatusOperationEnum",
    "ChangeStatusResourceTypeEnum",
    "ClickTypeEnum",
    "CombinedAudienceStatusEnum",
    "ConsentStatusEnum",
    "ContentLabelTypeEnum",
    "ConversionActionCategoryEnum",
    "ConversionActionCountingTypeEnum",
    "ConversionActionStatusEnum",
    "ConversionActionTypeEnum",
    "ConversionAdjustmentTypeEnum",
    "ConversionAttributionEventTypeEnum",
    "ConversionCustomVariableStatusEnum",
    "ConversionCustomerTypeEnum",
    "ConversionEnvironmentEnum",
    "ConversionLagBucketEnum",
    "ConversionOrAdjustmentLagBucketEnum",
    "ConversionOriginEnum",
    "ConversionTrackingStatusEnum",
    "ConversionValueRulePrimaryDimensionEnum",
    "ConversionValueRuleSetStatusEnum",
    "ConversionValueRuleStatusEnum",
    "ConvertingUserPriorEngagementTypeAndLtvBucketEnum",
    "CriterionCategoryChannelAvailabilityModeEnum",
    "CriterionCategoryLocaleAvailabilityModeEnum",
    "CriterionSystemServingStatusEnum",
    "CriterionTypeEnum",
    "CustomAudienceMemberTypeEnum",
    "CustomAudienceStatusEnum",
    "CustomAudienceTypeEnum",
    "CustomConversionGoalStatusEnum",
    "CustomInterestMemberTypeEnum",
    "CustomInterestStatusEnum",
    "CustomInterestTypeEnum",
    "CustomerAcquisitionOptimizationModeEnum",
    "CustomerLifecycleOptimizationModeEnum",
    "CustomerMatchUploadKeyTypeEnum",
    "CustomerPayPerConversionEligibilityFailureReasonEnum",
    "CustomerStatusEnum",
    "CustomizerAttributeStatusEnum",
    "CustomizerAttributeTypeEnum",
    "CustomizerValueStatusEnum",
    "DataDrivenModelStatusEnum",
    "DataLinkStatusEnum",
    "DataLinkTypeEnum",
    "DayOfWeekEnum",
    "DemandGenChannelConfigEnum",
    "DemandGenChannelStrategyEnum",
    "DeviceEnum",
    "DisplayAdFormatSettingEnum",
    "DisplayUploadProductTypeEnum",
    "DistanceBucketEnum",
    "EuPoliticalAdvertisingStatusEnum",
    "ExperimentMetricDirectionEnum",
    "ExperimentMetricEnum",
    "ExperimentStatusEnum",
    "ExperimentTypeEnum",
    "ExternalConversionSourceEnum",
    "FixedCpmGoalEnum",
    "FixedCpmTargetFrequencyTimeUnitEnum",
    "FrequencyCapEventTypeEnum",
    "FrequencyCapLevelEnum",
    "FrequencyCapTimeUnitEnum",
    "GenderTypeEnum",
    "GeoTargetConstantStatusEnum",
    "GeoTargetingTypeEnum",
    "GoalConfigLevelEnum",
    "GoalOptimizationEligibilityEnum",
    "GoalTypeEnum",
    "GoogleAdsFieldCategoryEnum",
    "GoogleAdsFieldDataTypeEnum",
    "GoogleVoiceCallStatusEnum",
    "HotelAssetSuggestionStatusEnum",
    "HotelDateSelectionTypeEnum",
    "HotelPriceBucketEnum",
    "HotelRateTypeEnum",
    "HotelReconciliationStatusEnum",
    "IdentityVerificationProgramEnum",
    "IdentityVerificationProgramStatusEnum",
    "IncentiveStateEnum",
    "IncomeRangeTypeEnum",
    "InsightsKnowledgeGraphEntityCapabilitiesEnum",
    "InsightsTrendEnum",
    "InteractionEventTypeEnum",
    "InteractionTypeEnum",
    "InvoiceTypeEnum",
    "KeywordMatchTypeEnum",
    "KeywordPlanAggregateMetricTypeEnum",
    "KeywordPlanCompetitionLevelEnum",
    "KeywordPlanConceptGroupTypeEnum",
    "KeywordPlanForecastIntervalEnum",
    "KeywordPlanKeywordAnnotationEnum",
    "KeywordPlanNetworkEnum",
    "LabelStatusEnum",
    "LandingPageSourceEnum",
    "LeadFormCallToActionTypeEnum",
    "LeadFormDesiredIntentEnum",
    "LeadFormFieldUserInputTypeEnum",
    "LeadFormPostSubmitCallToActionTypeEnum",
    "LegacyAppInstallAdAppStoreEnum",
    "LinkedAccountTypeEnum",
    "LinkedProductTypeEnum",
    "ListingGroupFilterCustomAttributeIndexEnum",
    "ListingGroupFilterListingSourceEnum",
    "ListingGroupFilterProductCategoryLevelEnum",
    "ListingGroupFilterProductChannelEnum",
    "ListingGroupFilterProductConditionEnum",
    "ListingGroupFilterProductTypeLevelEnum",
    "ListingGroupFilterTypeEnum",
    "ListingGroupTypeEnum",
    "ListingTypeEnum",
    "LocalServicesBusinessRegistrationCheckRejectionReasonEnum",
    "LocalServicesBusinessRegistrationTypeEnum",
    "LocalServicesCreditStateEnum",
    "LocalServicesEmployeeStatusEnum",
    "LocalServicesEmployeeTypeEnum",
    "LocalServicesInsuranceRejectionReasonEnum",
    "LocalServicesLeadConversationTypeEnum",
    "LocalServicesLeadCreditIssuanceDecisionEnum",
    "LocalServicesLeadStatusEnum",
    "LocalServicesLeadSurveyAnswerEnum",
    "LocalServicesLeadSurveyDissatisfiedReasonEnum",
    "LocalServicesLeadSurveySatisfiedReasonEnum",
    "LocalServicesLeadTypeEnum",
    "LocalServicesLicenseRejectionReasonEnum",
    "LocalServicesParticipantTypeEnum",
    "LocalServicesVerificationArtifactStatusEnum",
    "LocalServicesVerificationArtifactTypeEnum",
    "LocalServicesVerificationStatusEnum",
    "LocationGroupRadiusUnitsEnum",
    "LocationOwnershipTypeEnum",
    "LocationSourceTypeEnum",
    "LocationStringFilterTypeEnum",
    "LookalikeExpansionLevelEnum",
    "ManagerLinkStatusEnum",
    "MatchTypeEnum",
    "MediaTypeEnum",
    "MimeTypeEnum",
    "MinuteOfHourEnum",
    "MobileAppVendorEnum",
    "MobileDeviceTypeEnum",
    "MonthOfYearEnum",
    "NegativeGeoTargetTypeEnum",
    "NonSkippableMaxDurationEnum",
    "NonSkippableMinDurationEnum",
    "OfflineConversionDiagnosticStatusEnum",
    "OfflineEventUploadClientEnum",
    "OfflineUserDataJobFailureReasonEnum",
    "OfflineUserDataJobMatchRateRangeEnum",
    "OfflineUserDataJobStatusEnum",
    "OfflineUserDataJobTypeEnum",
    "OperatingSystemVersionOperatorTypeEnum",
    "OptimizationGoalTypeEnum",
    "ParentalStatusTypeEnum",
    "PaymentModeEnum",
    "PerformanceMaxUpgradeStatusEnum",
    "PlacementTypeEnum",
    "PolicyApprovalStatusEnum",
    "PolicyReviewStatusEnum",
    "PolicyTopicEntryTypeEnum",
    "PolicyTopicEvidenceDestinationMismatchUrlTypeEnum",
    "PolicyTopicEvidenceDestinationNotWorkingDeviceEnum",
    "PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum",
    "PositiveGeoTargetTypeEnum",
    "PriceExtensionPriceQualifierEnum",
    "PriceExtensionPriceUnitEnum",
    "PriceExtensionTypeEnum",
    "ProductAvailabilityEnum",
    "ProductCategoryLevelEnum",
    "ProductCategoryStateEnum",
    "ProductChannelEnum",
    "ProductChannelExclusivityEnum",
    "ProductConditionEnum",
    "ProductCustomAttributeIndexEnum",
    "ProductIssueSeverityEnum",
    "ProductLinkInvitationStatusEnum",
    "ProductStatusEnum",
    "ProductTypeLevelEnum",
    "PromotionBarcodeTypeEnum",
    "PromotionExtensionDiscountModifierEnum",
    "PromotionExtensionOccasionEnum",
    "ProximityRadiusUnitsEnum",
    "QualityScoreBucketEnum",
    "ReachPlanAgeRangeEnum",
    "ReachPlanConversionRateModelEnum",
    "ReachPlanNetworkEnum",
    "ReachPlanPlannableUserListStatusEnum",
    "ReachPlanSurfaceEnum",
    "RecommendationSubscriptionStatusEnum",
    "RecommendationTypeEnum",
    "RegulatoryFeeTypeEnum",
    "ResourceChangeOperationEnum",
    "ResourceLimitTypeEnum",
    "ResponseContentTypeEnum",
    "SearchEngineResultsPageTypeEnum",
    "SearchTermMatchSourceEnum",
    "SearchTermMatchTypeEnum",
    "SearchTermTargetingStatusEnum",
    "SeasonalityEventScopeEnum",
    "SeasonalityEventStatusEnum",
    "ServedAssetFieldTypeEnum",
    "SharedSetStatusEnum",
    "SharedSetTypeEnum",
    "ShoppingAddProductsToCampaignRecommendationEnum",
    "SimulationModificationMethodEnum",
    "SimulationTypeEnum",
    "SkAdNetworkAdEventTypeEnum",
    "SkAdNetworkAttributionCreditEnum",
    "SkAdNetworkCoarseConversionValueEnum",
    "SkAdNetworkSourceTypeEnum",
    "SkAdNetworkUserTypeEnum",
    "SlotEnum",
    "SmartCampaignNotEligibleReasonEnum",
    "SmartCampaignStatusEnum",
    "SpendingLimitTypeEnum",
    "SummaryRowSettingEnum",
    "SystemManagedResourceSourceEnum",
    "TargetCpaOptInRecommendationGoalEnum",
    "TargetFrequencyTimeUnitEnum",
    "TargetImpressionShareLocationEnum",
    "TargetingDimensionEnum",
    "ThirdPartyBrandLiftIntegrationPartnerEnum",
    "ThirdPartyBrandSafetyIntegrationPartnerEnum",
    "ThirdPartyReachIntegrationPartnerEnum",
    "ThirdPartyViewabilityIntegrationPartnerEnum",
    "TimeTypeEnum",
    "TrackingCodePageFormatEnum",
    "TrackingCodeTypeEnum",
    "UnitOfMeasureEnum",
    "UserIdentifierSourceEnum",
    "UserInterestTaxonomyTypeEnum",
    "UserListAccessStatusEnum",
    "UserListClosingReasonEnum",
    "UserListCrmDataSourceTypeEnum",
    "UserListCustomerTypeCategoryEnum",
    "UserListDateRuleItemOperatorEnum",
    "UserListFlexibleRuleOperatorEnum",
    "UserListLogicalRuleOperatorEnum",
    "UserListMembershipStatusEnum",
    "UserListNumberRuleItemOperatorEnum",
    "UserListPrepopulationStatusEnum",
    "UserListRuleTypeEnum",
    "UserListSizeRangeEnum",
    "UserListStringRuleItemOperatorEnum",
    "UserListTypeEnum",
    "ValueRuleDeviceTypeEnum",
    "ValueRuleGeoLocationMatchTypeEnum",
    "ValueRuleOperationEnum",
    "ValueRuleSetAttachmentTypeEnum",
    "ValueRuleSetDimensionEnum",
    "VanityPharmaDisplayUrlModeEnum",
    "VanityPharmaTextEnum",
    "VerticalAdsItemVerticalTypeEnum",
    "VideoAdFormatRestrictionEnum",
    "VideoAdSequenceInteractionTypeEnum",
    "VideoAdSequenceMinimumDurationEnum",
    "VideoThumbnailEnum",
    "WebpageConditionOperandEnum",
    "WebpageConditionOperatorEnum",
    "YouTubeVideoPropertyEnum",
]



from collections.abc import Mapping
from typing import Any, NoReturn, TypeVar

import google.protobuf.message
import proto
from typing_extensions import Literal

_M = TypeVar("_M")

class RecommendationErrorEnum(proto.Message):
    class RecommendationError(proto.Enum):
        UNSPECIFIED = 0
        UNKNOWN = 1
        BUDGET_AMOUNT_TOO_SMALL = 2
        BUDGET_AMOUNT_TOO_LARGE = 3
        INVALID_BUDGET_AMOUNT = 4
        POLICY_ERROR = 5
        INVALID_BID_AMOUNT = 6
        ADGROUP_KEYWORD_LIMIT = 7
        RECOMMENDATION_ALREADY_APPLIED = 8
        RECOMMENDATION_INVALIDATED = 9
        TOO_MANY_OPERATIONS = 10
        NO_OPERATIONS = 11
        DIFFERENT_TYPES_NOT_SUPPORTED = 12
        DUPLICATE_RESOURCE_NAME = 13
        RECOMMENDATION_ALREADY_DISMISSED = 14
        INVALID_APPLY_REQUEST = 15
        RECOMMENDATION_TYPE_APPLY_NOT_SUPPORTED = 17
        INVALID_MULTIPLIER = 18
        ADVERTISING_CHANNEL_TYPE_GENERATE_NOT_SUPPORTED = 19
        RECOMMENDATION_TYPE_GENERATE_NOT_SUPPORTED = 20
        RECOMMENDATION_TYPES_CANNOT_BE_EMPTY = 21
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_REQUIRES_BIDDING_INFO = 22
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_REQUIRES_BIDDING_STRATEGY_TYPE = 23
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_REQUIRES_ASSET_GROUP_INFO = 24
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_REQUIRES_ASSET_GROUP_INFO_WITH_FINAL_URL = (
            25
        )
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_REQUIRES_COUNTRY_CODES_FOR_SEARCH_CHANNEL = 26
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_INVALID_COUNTRY_CODE_FOR_SEARCH_CHANNEL = 27
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_REQUIRES_LANGUAGE_CODES_FOR_SEARCH_CHANNEL = 28
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_REQUIRES_EITHER_POSITIVE_OR_NEGATIVE_LOCATION_IDS_FOR_SEARCH_CHANNEL = 29
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_REQUIRES_AD_GROUP_INFO_FOR_SEARCH_CHANNEL = 30
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_REQUIRES_KEYWORDS_FOR_SEARCH_CHANNEL = 31
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_WITH_CHANNEL_TYPE_SEARCH_AND_BIDDING_STRATEGY_TYPE_TARGET_IMPRESSION_SHARE_REQUIRES_LOCATION = 32
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_WITH_CHANNEL_TYPE_SEARCH_AND_BIDDING_STRATEGY_TYPE_TARGET_IMPRESSION_SHARE_REQUIRES_TARGET_IMPRESSION_SHARE_MICROS = 33
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_TARGET_IMPRESSION_SHARE_MICROS_BETWEEN_1_AND_1000000 = 34
        CAMPAIGN_BUDGET_RECOMMENDATION_TYPE_WITH_CHANNEL_TYPE_SEARCH_AND_BIDDING_STRATEGY_TYPE_TARGET_IMPRESSION_SHARE_REQUIRES_TARGET_IMPRESSION_SHARE_INFO = 35
        MERCHANT_CENTER_ACCOUNT_ID_NOT_SUPPORTED_ADVERTISING_CHANNEL_TYPE = 36

    def __init__(
        self: _M,
        mapping: _M | Mapping | google.protobuf.message.Message | None = None,
        *,
        ignore_unknown_fields: bool = False,
    ) -> None: ...
    def __contains__(  # type: ignore[override]
        self, key: NoReturn
    ) -> bool: ...
